@@ -28,6 +28,9 @@ JAVA_ENABLED=True
 GIT_HASH=False
 PYTHON_ENABLED=True
 MAKEJOBS=getenv("MAKEJOBS", '8')
+OS_NAME=None
+LINUX_X64=mk_util.LINUX_X64
+HOST_IS_ARM64=mk_util.IS_ARCH_ARM64  # Save the original host architecture
 
 def set_verbose(flag):
     global VERBOSE
@@ -56,14 +59,16 @@ def display_help():
     print("  -f, --force                   force script to regenerate Makefiles.")
     print("  --nodotnet                    do not include .NET bindings in the binary distribution files.")
     print("  --dotnet-key=<file>           sign the .NET assembly with the private key in <file>.")
+    print("  --arch=<arch>                 set architecture (arm64 or x64) to force cross-compilation")
     print("  --nojava                      do not include Java bindings in the binary distribution files.")
+    print("  --os=<os>                     set OS version.")
     print("  --nopython                    do not include Python bindings in the binary distribution files.")
     print("  --githash                     include git hash in the Zip file.")
     exit(0)
 
 # Parse configuration option for mk_make script
 def parse_options():
-    global FORCE_MK, JAVA_ENABLED, GIT_HASH, DOTNET_CORE_ENABLED, DOTNET_KEY_FILE
+    global FORCE_MK, JAVA_ENABLED, GIT_HASH, DOTNET_CORE_ENABLED, DOTNET_KEY_FILE, PYTHON_ENABLED, OS_NAME, LINUX_X64
     path = BUILD_DIR
     options, remainder = getopt.gnu_getopt(sys.argv[1:], 'b:hsf', ['build=',
                                                                    'help',
@@ -72,6 +77,8 @@ def parse_options():
                                                                    'nojava',
                                                                    'nodotnet',
                                                                    'dotnet-key=',
+                                                                   'arch=',
+                                                                   'os=',
                                                                    'githash',
                                                                    'nopython'
                                                                    ])
@@ -96,6 +103,16 @@ def parse_options():
             JAVA_ENABLED = False
         elif opt == '--githash':
             GIT_HASH = True
+        elif opt == '--arch':
+            if arg == "arm64":
+                mk_util.IS_ARCH_ARM64 = True
+            elif arg == "x64":
+                mk_util.IS_ARCH_ARM64 = False
+                LINUX_X64 = True
+            else:
+                raise MKException("Invalid architecture directive '%s'. Legal directives: arm64, x64" % arg)
+        elif opt == '--os':
+            OS_NAME = arg
         else:
             raise MKException("Invalid command line option '%s'" % opt)
     set_build_dir(path)
@@ -106,7 +123,9 @@ def check_build_dir(path):
 
 # Create a build directory using mk_make.py
 def mk_build_dir(path):
+    global LINUX_X64, HOST_IS_ARM64
     if not check_build_dir(path) or FORCE_MK:
+        env = os.environ
         opts = [sys.executable, os.path.join('scripts', 'mk_make.py'), "-b", path, "--staticlib"]
         if DOTNET_CORE_ENABLED:
             opts.append('--dotnet')
@@ -119,7 +138,31 @@ def mk_build_dir(path):
             opts.append('--git-describe')
         if PYTHON_ENABLED:
             opts.append('--python')
-        if subprocess.call(opts) != 0:
+        if mk_util.IS_ARCH_ARM64:
+            opts.append('--arm64=true')
+        if mk_util.IS_ARCH_ARM64 and LINUX_X64:
+            # we are on x64 machine but build for arm64
+            # so we have to do cross compiling on Linux
+            # the cross compiler is downloaded from ARM GNU toolchain
+            myvar = {
+                "CC":  "aarch64-none-linux-gnu-gcc",
+                "CXX": "aarch64-none-linux-gnu-g++"
+            }
+            env.update(myvar)
+        elif HOST_IS_ARM64 and not mk_util.IS_ARCH_ARM64:
+            # we are on arm64 machine but build for x64
+            # handle cross compilation on macOS (or other Unix systems)
+            import platform
+            if platform.system() == 'Darwin':
+                # On macOS, we can cross-compile using -arch flag
+                target_arch_flag = ' -arch x86_64'
+                myvar = {
+                    "CXXFLAGS": (os.environ.get("CXXFLAGS", "").strip() + target_arch_flag).strip(),
+                    "CFLAGS": (os.environ.get("CFLAGS", "").strip() + target_arch_flag).strip(),
+                    "LDFLAGS": (os.environ.get("LDFLAGS", "").strip() + target_arch_flag).strip()
+                }
+                env.update(myvar)
+        if subprocess.call(opts, env=env) != 0:
             raise MKException("Failed to generate build directory at '%s'" % path)
 
 # Create build directories
@@ -145,10 +188,22 @@ def mk_z3():
             return 1
 
 def get_os_name():
+    global LINUX_X64
+    if OS_NAME is not None:
+        return OS_NAME
     import platform
     basic = os.uname()[0].lower()
     if basic == 'linux':
-        dist = platform.libc_ver()
+        if mk_util.IS_ARCH_ARM64 and LINUX_X64:
+            # handle cross compiling
+            # example: 'ldd (GNU) 2.34'
+            lines = subprocess.check_output(["ldd", "--version"]).decode('ascii')
+            first_line = lines.split("\n")[0]
+            ldd_version = first_line.split()[-1]
+            # coerce the format to platform.libc_ver() return type
+            dist = ('glibc', ldd_version)
+        else:
+            dist = platform.libc_ver()
         if len(dist) == 2 and len(dist[0]) > 0 and len(dist[1]) > 0:
             return '%s-%s' % (dist[0].lower(), dist[1].lower())
         else:
@@ -171,8 +226,16 @@ def get_os_name():
         return basic
 
 def get_z3_name():
+    import platform as platform_module
+    # Note that the platform name this function return
+    # has to work together with setup.py
+    # It's not the typical output from platform.machine()
     major, minor, build, revision = get_version()
-    if sys.maxsize >= 2**32:
+    if mk_util.IS_ARCH_ARM64 or platform_module.machine() == "aarch64":
+        # the second case handle native build on aarch64
+        # TODO: we don't handle cross compile on host aarch64 to target x64
+        platform = "arm64"    
+    elif sys.maxsize >= 2**32:
         platform = "x64"
     else:
         platform = "x86"
