@@ -50,8 +50,8 @@ namespace Microsoft.Z3
         {
             get
             {
-                int res = 0;
-                if (Native.Z3_fpa_get_numeral_sign(Context.nCtx, NativeObject, ref res) == 0)
+                byte res = 0;
+                if (0 == Native.Z3_fpa_get_numeral_sign(Context.nCtx, NativeObject, ref res))
                     throw new Z3Exception("Sign is not a Boolean value");
                 return res != 0;
             }
