@@ -17,28 +17,27 @@ Notes:
     
 --*/
 
+using System.Diagnostics;
 using System;
-using System.Diagnostics.Contracts;
 
 namespace Microsoft.Z3
 {
     /// <summary>
     /// Set sorts.
     /// </summary>
-    [ContractVerification(true)]
     public class SetSort : Sort
     {
         #region Internal
         internal SetSort(Context ctx, IntPtr obj)
             : base(ctx, obj)
         {
-            Contract.Requires(ctx != null);
+            Debug.Assert(ctx != null);
         }
         internal SetSort(Context ctx, Sort ty)
             : base(ctx, Native.Z3_mk_set_sort(ctx.nCtx, ty.NativeObject))
         {
-            Contract.Requires(ctx != null);
-            Contract.Requires(ty != null);
+            Debug.Assert(ctx != null);
+            Debug.Assert(ty != null);
         }
         #endregion
     }
