@@ -34,7 +34,7 @@ unsigned get_num_nodes(ast * n) {
 
 bool for_each_parameter(ptr_vector<ast> & stack, ast_mark & visited, unsigned num_args, parameter const * params) {
     bool result = true;
-    for (unsigned i = 0; i < num_args; i++) {
+    for (unsigned i = 0; i < num_args; ++i) {
         parameter const& p = params[i];
         if (p.is_ast() && !visited.is_marked(p.get_ast())) {
             stack.push_back(p.get_ast());
