@@ -143,7 +143,7 @@ bool macro_util::is_macro_head(expr * n, unsigned num_decls) const {
         to_app(n)->get_num_args() == num_decls) {
         sbuffer<int> var2pos;
         var2pos.resize(num_decls, -1);
-        for (unsigned i = 0; i < num_decls; i++) {
+        for (unsigned i = 0; i < num_decls; ++i) {
             expr * c = to_app(n)->get_arg(i);
             if (!is_var(c))
                 return false;
@@ -252,7 +252,7 @@ bool macro_util::poly_contains_head(expr * n, func_decl * f, expr * exception) c
         num_args = 1;
         args     = &n;
     }
-    for (unsigned i = 0; i < num_args; i++) {
+    for (unsigned i = 0; i < num_args; ++i) {
         expr * arg = args[i];
         if (arg != exception && occurs(f, arg))
             return true;
@@ -283,7 +283,7 @@ bool macro_util::is_arith_macro(expr * n, unsigned num_decls, app_ref & head, ex
         lhs_num_args = 1;
         lhs_args     = &lhs;
     }
-    for (unsigned i = 0; i < lhs_num_args; i++) {
+    for (unsigned i = 0; i < lhs_num_args; ++i) {
         expr * arg = lhs_args[i];
         expr * neg_arg;
         if (h == nullptr &&
@@ -312,7 +312,7 @@ bool macro_util::is_arith_macro(expr * n, unsigned num_decls, app_ref & head, ex
         mk_sub(tmp, rhs, def);
     else
         mk_sub(rhs, tmp, def);
-    TRACE("macro_util", tout << def << "\n";);
+    TRACE(macro_util, tout << def << "\n";);
     return true;
 }
 
@@ -351,7 +351,7 @@ bool macro_util::is_pseudo_head(expr * n, unsigned num_decls, app_ref & head, ap
 bool macro_util::is_pseudo_predicate_macro(expr * n, app_ref & head, app_ref & t, expr_ref & def) {
     if (!is_forall(n))
         return false;
-    TRACE("macro_util", tout << "processing: " << mk_pp(n, m) << "\n";);
+    TRACE(macro_util, tout << "processing: " << mk_pp(n, m) << "\n";);
     expr * body        = to_quantifier(n)->get_expr();
     unsigned num_decls = to_quantifier(n)->get_num_decls();
     expr * lhs, *rhs;
@@ -392,7 +392,7 @@ bool macro_util::is_quasi_macro_head(expr * n, unsigned num_decls) const {
         sbuffer<bool> found_vars;
         found_vars.resize(num_decls, false);
         unsigned num_found_vars = 0;
-        for (unsigned i = 0; i < num_args; i++) {
+        for (unsigned i = 0; i < num_args; ++i) {
             expr * arg = to_app(n)->get_arg(i);
             if (is_var(arg)) {
                 unsigned idx = to_var(arg)->get_idx();
@@ -429,7 +429,7 @@ bool macro_util::is_quasi_macro_ok(expr * n, unsigned num_decls, expr * def) con
         }
         if (def)
             fv.accumulate(def);
-        for (unsigned i = 0; i < fv.size(); i++) {
+        for (unsigned i = 0; i < fv.size(); ++i) {
             if (i >= num_decls || !fv.contains(i))
                 continue; // Quasi-macros may have new variables.
             if (found_vars[i] == false) {
@@ -453,7 +453,7 @@ void macro_util::quasi_macro_head_to_macro_head(app * qhead, unsigned & num_decl
     ptr_buffer<expr> new_args;
     ptr_buffer<expr> new_conds;
     unsigned next_var_idx = num_decls;
-    for (unsigned i = 0; i < num_args; i++) {
+    for (unsigned i = 0; i < num_args; ++i) {
         expr * arg = qhead->get_arg(i);
         if (is_var(arg)) {
             unsigned idx = to_var(arg)->get_idx();
@@ -483,7 +483,7 @@ void macro_util::quasi_macro_head_to_macro_head(app * qhead, unsigned & num_decl
    See normalize_expr
 */
 void macro_util::mk_macro_interpretation(app * head, unsigned num_decls, expr * def, expr_ref & interp) const {
-    TRACE("macro_util", tout << mk_pp(head, m) << "\n" << mk_pp(def, m) << "\n";);
+    TRACE(macro_util, tout << mk_pp(head, m) << "\n" << mk_pp(def, m) << "\n";);
     SASSERT(is_macro_head(head, head->get_num_args()) ||
             is_quasi_macro_ok(head, head->get_num_args(), def));
     SASSERT(!occurs(head->get_decl(), def));
@@ -505,10 +505,10 @@ void macro_util::normalize_expr(app * head, unsigned num_decls, expr * t, expr_r
     var_mapping.resize(num_decls);
     bool changed = false;
     unsigned num_args = head->get_num_args();
-    TRACE("macro_util",
+    TRACE(macro_util,
           tout << "head: " << mk_pp(head, m) << "\n";
           tout << "applying substitution to:\n" << mk_bounded_pp(t, m) << "\n";);
-    for (unsigned i = 0; i < num_args; i++) {
+    for (unsigned i = 0; i < num_args; ++i) {
         var * v = to_var(head->get_arg(i));
         unsigned vi = v->get_idx();
         SASSERT(vi < num_decls);
@@ -524,10 +524,10 @@ void macro_util::normalize_expr(app * head, unsigned num_decls, expr * t, expr_r
     if (changed) {
         // REMARK: t may have nested quantifiers... So, I must use the std order for variable substitution.
         var_subst subst(m, true);
-        TRACE("macro_util",
+        TRACE(macro_util,
               tout << "head: " << mk_pp(head, m) << "\n";
               tout << "applying substitution to:\n" << mk_ll_pp(t, m) << "\nsubstitution:\n";
-              for (unsigned i = 0; i < var_mapping.size(); i++) {
+              for (unsigned i = 0; i < var_mapping.size(); ++i) {
                   if (var_mapping[i] != 0)
                       tout << "#" << i << " -> " << mk_ll_pp(var_mapping[i], m);
               });
@@ -633,12 +633,12 @@ void hint_to_macro_head(ast_manager & m, app * head, unsigned & num_decls, app_r
    is_hint_head(head, vars) must also return true
 */
 bool macro_util::is_poly_hint(expr * n, app * head, expr * exception) {
-    TRACE("macro_util", tout << "is_poly_hint n:\n" << mk_pp(n, m) << "\nhead:\n" << mk_pp(head, m) << "\nexception:\n";
+    TRACE(macro_util, tout << "is_poly_hint n:\n" << mk_pp(n, m) << "\nhead:\n" << mk_pp(head, m) << "\nexception:\n";
           if (exception) tout << mk_pp(exception, m); else tout << "<null>";
           tout << "\n";);
     ptr_buffer<var> vars;
     if (!is_hint_head(head, vars)) {
-        TRACE("macro_util", tout << "failed because head is not hint head\n";);
+        TRACE(macro_util, tout << "failed because head is not hint head\n";);
         return false;
     }
     func_decl * f = head->get_decl();
@@ -652,14 +652,14 @@ bool macro_util::is_poly_hint(expr * n, app * head, expr * exception) {
         num_args = 1;
         args     = &n;
     }
-    for (unsigned i = 0; i < num_args; i++) {
+    for (unsigned i = 0; i < num_args; ++i) {
         expr * arg = args[i];
         if (arg != exception && (occurs(f, arg) || !vars_of_is_subset(arg, vars))) {
-            TRACE("macro_util", tout << "failed because of:\n" << mk_pp(arg, m) << "\n";);
+            TRACE(macro_util, tout << "failed because of:\n" << mk_pp(arg, m) << "\n";);
             return false;
         }
     }
-    TRACE("macro_util", tout << "succeeded\n";);
+    TRACE(macro_util, tout << "succeeded\n";);
     return true;
 
 }
@@ -714,7 +714,7 @@ void macro_util::insert_macro(app * head, unsigned num_decls, expr * def, expr *
 
 void macro_util::insert_quasi_macro(app * head, unsigned num_decls, expr * def, expr * cond, bool ineq, bool satisfy_atom,
                                     bool hint, macro_candidates & r) {
-    TRACE("macro_util", tout << expr_ref(head, m) << "\n";);
+    TRACE(macro_util, tout << expr_ref(head, m) << "\n";);
     if (!is_macro_head(head, head->get_num_args())) {
         app_ref  new_head(m);
         expr_ref extra_cond(m);
@@ -728,7 +728,7 @@ void macro_util::insert_quasi_macro(app * head, unsigned num_decls, expr * def,
         }
         else {
             hint_to_macro_head(m, head, num_decls, new_head);
-            TRACE("macro_util",
+            TRACE(macro_util,
                 tout << "hint macro head: " << mk_ismt2_pp(new_head, m) << std::endl;
                 tout << "hint macro def: " << mk_ismt2_pp(def, m) << std::endl; );
         }
@@ -744,7 +744,7 @@ bool macro_util::rest_contains_decl(func_decl * f, expr * except_lit) {
         return false;
     SASSERT(is_clause(m, m_curr_clause));
     unsigned num_lits = get_clause_num_literals(m, m_curr_clause);
-    for (unsigned i = 0; i < num_lits; i++) {
+    for (unsigned i = 0; i < num_lits; ++i) {
         expr * l = get_clause_literal(m, m_curr_clause, i);
         if (l != except_lit && occurs(f, l))
             return true;
@@ -758,7 +758,7 @@ void macro_util::get_rest_clause_as_cond(expr * except_lit, expr_ref & extra_con
     SASSERT(is_clause(m, m_curr_clause));
     expr_ref_buffer neg_other_lits(m);
     unsigned num_lits = get_clause_num_literals(m, m_curr_clause);
-    for (unsigned i = 0; i < num_lits; i++) {
+    for (unsigned i = 0; i < num_lits; ++i) {
         expr * l = get_clause_literal(m, m_curr_clause, i);
         if (l != except_lit) {
             expr_ref neg_l(m);
@@ -783,7 +783,7 @@ void macro_util::collect_poly_args(expr * n, expr * exception, ptr_buffer<expr>
         num_args = 1;
         _args     = &n;
     }
-    for (unsigned i = 0; i < num_args; i++) {
+    for (unsigned i = 0; i < num_args; ++i) {
         expr * arg = _args[i];
         if (arg != exception)
             args.push_back(arg);
@@ -811,7 +811,7 @@ void macro_util::collect_arith_macro_candidates(expr * lhs, expr * rhs, expr * a
         lhs_num_args = 1;
         lhs_args     = &lhs;
     }
-    for (unsigned i = 0; i < lhs_num_args; i++) {
+    for (unsigned i = 0; i < lhs_num_args; ++i) {
         expr * arg = lhs_args[i];
         expr * neg_arg;
         if (!is_app(arg))
@@ -863,7 +863,7 @@ void macro_util::collect_arith_macro_candidates(expr * lhs, expr * rhs, expr * a
 }
 
 void macro_util::collect_arith_macro_candidates(expr * atom, unsigned num_decls, macro_candidates & r) {
-    TRACE("macro_util", tout << "collect_arith_macro_candidates:\n" << mk_pp(atom, m) << "\n";);
+    TRACE(macro_util, tout << "collect_arith_macro_candidates:\n" << mk_pp(atom, m) << "\n";);
     if (!m.is_eq(atom) && !is_le_ge(atom))
         return;
     expr * lhs = to_app(atom)->get_arg(0);
@@ -912,7 +912,7 @@ void macro_util::collect_arith_macro_candidates(expr * atom, unsigned num_decls,
 void macro_util::collect_macro_candidates_core(expr * atom, unsigned num_decls, macro_candidates & r) {
     expr* lhs, *rhs;
 
-    TRACE("macro_util", tout << "Candidate check for: " << mk_ismt2_pp(atom, m) << std::endl;);
+    TRACE(macro_util, tout << "Candidate check for: " << mk_ismt2_pp(atom, m) << std::endl;);
 
     auto insert_quasi = [&](expr* lhs, expr* rhs) {
         if (is_quasi_macro_head(lhs, num_decls) &&
@@ -967,7 +967,7 @@ void macro_util::collect_macro_candidates(quantifier * q, macro_candidates & r)
     if (is_clause(m, n)) {
         m_curr_clause = n;
         unsigned num_lits = get_clause_num_literals(m, n);
-        for (unsigned i = 0; i < num_lits; i++)
+        for (unsigned i = 0; i < num_lits; ++i)
             collect_macro_candidates_core(get_clause_literal(m, n, i), num_decls, r);
         m_curr_clause = nullptr;
     }
