@@ -38,7 +38,7 @@ namespace sls {
         family_id m_fid;
     public:
         plugin(context& c);
-        virtual ~plugin() {}
+        virtual ~plugin() = default;
         virtual family_id fid() { return m_fid; }
         virtual void register_term(expr* e) = 0;
         virtual expr_ref get_value(expr* e) = 0;
@@ -65,7 +65,7 @@ namespace sls {
 
     class sat_solver_context {
     public:
-        virtual ~sat_solver_context() {}
+        virtual ~sat_solver_context() = default;
         virtual vector<sat::clause_info> const& clauses() const = 0;
         virtual sat::clause_info const& get_clause(unsigned idx) const = 0;
         virtual ptr_iterator<unsigned> get_use_list(sat::literal lit) = 0;
@@ -86,6 +86,7 @@ namespace sls {
         virtual void force_restart() = 0;
         virtual std::ostream& display(std::ostream& out) = 0;
         virtual reslimit& rlimit() = 0;
+        virtual unsigned timestamp(sat::bool_var v) = 0;
     };
     
     class context {
@@ -195,6 +196,7 @@ namespace sls {
         void shift_weights() { s.shift_weights(); }
         bool try_rotate(sat::bool_var v, sat::bool_var_set& rotated, unsigned& budget) { return s.try_rotate(v, rotated, budget); }
         double reward(sat::bool_var v) { return s.reward(v); }
+        unsigned timestamp(sat::bool_var v) { return s.timestamp(v); }
         indexed_uint_set const& unsat() const { return s.unsat(); }
         indexed_uint_set const& unsat_vars() const { return s.unsat_vars(); }
         unsigned num_external_in_unsat_vars() const { return s.num_external_in_unsat_vars(); }
