@@ -26,10 +26,10 @@ Revision History:
 #include "ast/ast.h"
 
 class expr_offset {
-    expr *    m_expr;
-    unsigned  m_offset;
+    expr *    m_expr = nullptr;
+    unsigned  m_offset = 0;
 public:
-    expr_offset():m_expr(nullptr), m_offset(0) {}
+    expr_offset() = default;
     expr_offset(expr * e, unsigned o):m_expr(e), m_offset(o) {}
     
     expr * get_expr() const { return m_expr; }
