@@ -70,7 +70,7 @@ inline void substitution_tree::erase_reg_from_todo(unsigned ridx) {
 */
 void substitution_tree::linearize(svector<subst> & result) {
     ptr_buffer<expr> new_args;
-    for (unsigned i = 0; i < m_todo.size(); i++) {
+    for (unsigned i = 0; i < m_todo.size(); ++i) {
         unsigned ireg_idx = m_todo[i];
         expr * n          = get_reg_value(ireg_idx);
         var * ireg        = m_manager.mk_var(ireg_idx, n->get_sort());
@@ -83,7 +83,7 @@ void substitution_tree::linearize(svector<subst> & result) {
             if (num == 0)
                 new_app = to_app(n);
             else {
-                for (unsigned j = 0; j < num; j++) {
+                for (unsigned j = 0; j < num; ++j) {
                     unsigned oreg     = next_reg();
                     set_reg_value(oreg, to_app(n)->get_arg(j));
                     m_todo.push_back(oreg);
@@ -106,10 +106,10 @@ void substitution_tree::linearize(svector<subst> & result) {
    If save_set_registers == true, then r_i's are stored in m_to_reset.
 */
 void substitution_tree::process_args(app * in, app * out) {
-    CTRACE("subst_tree_bug", in->get_num_args() != out->get_num_args(), tout << mk_ismt2_pp(in, m_manager) << "\n" 
+    CTRACE(subst_tree_bug, in->get_num_args() != out->get_num_args(), tout << mk_ismt2_pp(in, m_manager) << "\n" 
            << mk_ismt2_pp(out, m_manager) << "\n";);
     unsigned num = out->get_num_args();
-    for (unsigned i = 0; i < num; i++) {
+    for (unsigned i = 0; i < num; ++i) {
         expr * in_arg  = in->get_arg(i);
         expr * out_arg = out->get_arg(i);
         SASSERT(is_var(out_arg));
@@ -232,7 +232,7 @@ void substitution_tree::mark_used_regs(svector<subst> const & sv) {
         mark_used_reg(s.first->get_idx());
         if (is_app(s.second)) {
             unsigned num_args = to_app(s.second)->get_num_args();
-            for (unsigned i = 0; i < num_args; i++) {
+            for (unsigned i = 0; i < num_args; ++i) {
                 expr * arg = to_app(s.second)->get_arg(i);
                 SASSERT(is_var(arg));
                 mark_used_reg(to_var(arg)->get_idx());
@@ -578,9 +578,9 @@ void substitution_tree::display(std::ostream & out, subst const & s) const {
             out << to_app(s.second)->get_decl()->get_name();
         else {
             out << "(" << to_app(s.second)->get_decl()->get_name();
-            for (unsigned i = 0; i < num; i++)
+            for (unsigned i = 0; i < num; ++i)
                 out << " r!" << to_var(to_app(s.second)->get_arg(i))->get_idx();
-            out << ")";
+            out << ')';
         }
     }
     else {
@@ -600,7 +600,7 @@ void substitution_tree::display(std::ostream & out, svector<subst> const & sv) c
 }
 
 void substitution_tree::display(std::ostream & out, node * n, unsigned delta) const {
-    for (unsigned i = 0; i < delta; i++) 
+    for (unsigned i = 0; i < delta; ++i) 
         out << "  ";
     display(out, n->m_subst);
     if (n->m_leaf) {
@@ -622,7 +622,7 @@ void substitution_tree::display(std::ostream & out, node * n, unsigned delta) co
 
 bool substitution_tree::backtrack() {
     while (!m_bstack.empty()) {
-        TRACE("st", tout << "backtracking...\n";);
+        TRACE(st, tout << "backtracking...\n";);
         m_subst->pop_scope();
 
         node * n = m_bstack.back();
@@ -636,9 +636,9 @@ bool substitution_tree::backtrack() {
 }
 
 inline expr_offset substitution_tree::find(expr_offset p) {
-    TRACE("substitution_tree_bug", tout << "find...\n";);
+    TRACE(substitution_tree_bug, tout << "find...\n";);
     while (is_var(p.get_expr())) {
-        TRACE("substitution_tree_bug", tout << mk_pp(p.get_expr(), m_manager) << " " << p.get_offset() << "\n";);
+        TRACE(substitution_tree_bug, tout << mk_pp(p.get_expr(), m_manager) << " " << p.get_offset() << "\n";);
         if (!m_subst->find(to_var(p.get_expr()), p.get_offset(), p))
             return p;
     }
@@ -647,7 +647,7 @@ inline expr_offset substitution_tree::find(expr_offset p) {
 
 template<substitution_tree::st_visit_mode Mode>
 bool substitution_tree::bind_var(var * v, unsigned offset, expr_offset const & p) {
-    TRACE("st", tout << "bind_var: " << mk_pp(v, m_manager) << " " << offset << "\n" << 
+    TRACE(st, tout << "bind_var: " << mk_pp(v, m_manager) << " " << offset << "\n" << 
           mk_pp(p.get_expr(), m_manager) << " " << p.get_offset() << "\n";);
     if (Mode == STV_INST && offset == m_st_offset) {
         SASSERT(!is_var(p.get_expr()) || p.get_offset() != m_reg_offset);
@@ -666,7 +666,7 @@ bool substitution_tree::bind_var(var * v, unsigned offset, expr_offset const & p
         return false;
     }
     m_subst->insert(v, offset, p);
-    TRACE("st_bug", tout << "substitution updated\n"; m_subst->display(tout););
+    TRACE(st_bug, tout << "substitution updated\n"; m_subst->display(tout););
     return true;
 }
 
@@ -687,7 +687,7 @@ bool substitution_tree::unify_match(expr_offset p1, expr_offset p2) {
             SASSERT(!is_quantifier(n2));
             bool v1 = is_var(n1);
             bool v2 = is_var(n2);
-            TRACE("st", 
+            TRACE(st, 
                   tout << "n1: " << mk_pp(n1, m_manager) << " " << p1.get_offset() << "\n";
                   tout << "n2: " << mk_pp(n2, m_manager) << " " << p2.get_offset() << "\n";);
             if (v1 && v2) {
@@ -734,7 +734,7 @@ bool substitution_tree::visit_vars(expr * e, st_visitor & st) {
         var_ref_vector * v = m_vars[s_id];
         if (v && !v->empty()) {
             unsigned sz = v->size();
-            for (unsigned i = 0; i < sz; i++) {
+            for (unsigned i = 0; i < sz; ++i) {
                 var * curr = v->get(i);
                 m_subst->push_scope();
                 if (unify_match<Mode>(expr_offset(curr, m_st_offset), expr_offset(e, m_in_offset))) {
@@ -758,7 +758,7 @@ bool substitution_tree::visit(svector<subst> const & sv) {
     svector<subst>::const_iterator end = sv.end();
     for (; it != end; ++it) {
         subst const & s = *it;
-        TRACE("st", tout << "processing subst:\n"; display(tout, s); tout << "\n";);
+        TRACE(st, tout << "processing subst:\n"; display(tout, s); tout << "\n";);
         var *  rin  = s.first;
         expr * out  = s.second; 
         expr_offset p1(rin, m_reg_offset);
@@ -778,9 +778,9 @@ bool substitution_tree::visit(expr * e, st_visitor & st, node * r) {
 
     while (true) {
         node * n = m_bstack.back();
-        TRACE("st", tout << "push scope...\n";);
+        TRACE(st, tout << "push scope...\n";);
         m_subst->push_scope();
-        TRACE("st", tout << "processing node:\n"; display(tout, n->m_subst); tout << "\n";);
+        TRACE(st, tout << "processing node:\n"; display(tout, n->m_subst); tout << "\n";);
         if (visit<Mode>(n->m_subst)) {
             if (n->m_leaf) {
                 // if searching for unifiers and the substitution is cyclic, then backtrack.
@@ -789,7 +789,7 @@ bool substitution_tree::visit(expr * e, st_visitor & st, node * r) {
                         break;
                 }
                 else {
-                    TRACE("st_bug", tout << "found match:\n"; m_subst->display(tout); tout << "m_subst: " << m_subst << "\n";);
+                    TRACE(st_bug, tout << "found match:\n"; m_subst->display(tout); tout << "m_subst: " << m_subst << "\n";);
                     if (!st(n->m_expr)) {
                         clear_stack();
                         return false;
@@ -870,7 +870,7 @@ void substitution_tree::display(std::ostream & out) const {
         if (v == nullptr)
             continue; // m_vars may contain null pointers. See substitution_tree::insert.
         unsigned num = v->size();
-        for (unsigned i = 0; i < num; i++) {
+        for (unsigned i = 0; i < num; ++i) {
             if (!found_var) {
                 found_var = true;
                 out << "vars: ";
