@@ -274,7 +274,7 @@ private:
 
             if (premise) {
                 expr_ref f1 = bind_variables(mk_implies(m_body, head));
-                expr* f2 = m.mk_and(sz, m_todo.data()+m_todo.size()-sz);
+                expr* f2 = m.mk_and(std::span<expr* const>(m_todo.data()+m_todo.size()-sz, sz));
                 proof_ref p2(m), p3(m);
                 p2 = m.mk_def_axiom(m.mk_iff(f1, f2));
                 p3 = mk_quant_intro(fml, f1, p);                    
@@ -450,7 +450,7 @@ private:
         case 1: 
             return app_ref(m.mk_implies(body[0], head), m);
         default:
-            return app_ref(m.mk_implies(m.mk_and(body.size(), body.data()), head), m);
+            return app_ref(m.mk_implies(m.mk_and(body), head), m);
         }        
     }
 
