@@ -545,7 +545,7 @@ protected:
             result = tok == TK_EOS && m_error == false;
         }
         catch (z3_exception& ex) {
-            std::cerr << ex.msg() << std::endl;
+            std::cerr << ex.what() << std::endl;
             result = false;
         }
         return result;
@@ -1125,13 +1125,12 @@ protected:
        \brief Make a constant for DK_SYMBOL sort out of an integer
      */
     app* mk_symbol_const(uint64_t el, sort* s) {
-        uint64_t sz = 0;
         if (m_arith.is_int(s)) 
             return m_arith.mk_numeral(rational(el, rational::ui64()), s);
-        else if (m_decl_util.try_get_size(s, sz)) {
-            if (el >= sz) {
+        else if (auto sz = m_decl_util.try_get_size(s)) {
+            if (el >= *sz) {
                 std::ostringstream ous;
-                ous << "numeric value " << el << " is out of bounds of domain size " << sz;
+                ous << "numeric value " << el << " is out of bounds of domain size " << *sz;
                 throw default_exception(ous.str());
             }
             return m_decl_util.mk_numeral(el, s);
@@ -1225,7 +1224,7 @@ public:
             result = parse_directory_core(path);
         }
         catch (z3_exception& ex) {
-            std::cerr << ex.msg() << std::endl;
+            std::cerr << ex.what() << std::endl;
             return false;
         }
         return result;
@@ -1401,7 +1400,7 @@ private:
 
             bool fact_fail = false;
             fact.reset();
-            for(unsigned i=0;i<pred_arity; i++) {
+            for(unsigned i=0;i<pred_arity; ++i) {
                 uint64_t const_num = args[i];
                 table_element c;
                 if(!inp_num_to_element(arg_sorts[i], const_num, c)) {
