@@ -99,7 +99,7 @@ namespace datalog {
                     return false;
                 }
                 return memcmp(this->data(), o.data(), n*sizeof(sort))==0;
-                /*for (unsigned i=0; i<n; i++) {
+                /*for (unsigned i=0; i<n; ++i) {
                     if ((*this)[i]!=o[i]) {
                         return false;
                     }
@@ -116,15 +116,15 @@ namespace datalog {
                 result.reset();
 
                 unsigned s1sz=s1.size();
-                for (unsigned i=0; i<s1sz; i++) {
+                for (unsigned i=0; i<s1sz; ++i) {
                     result.push_back(s1[i]);
                 }
                 unsigned s2sz=s2.size();
-                for (unsigned i=0; i<s2sz; i++) {
+                for (unsigned i=0; i<s2sz; ++i) {
                     result.push_back(s2[i]);
                 }
 #if Z3DEBUG
-                for (unsigned i=0; i<col_cnt; i++) {
+                for (unsigned i=0; i<col_cnt; ++i) {
                     SASSERT(cols1[i]<s1sz);
                     SASSERT(cols2[i]<s2sz);
                 }
@@ -170,7 +170,7 @@ namespace datalog {
                     const unsigned * permutation, signature & result) {
                 result.reset();
                 unsigned n = src.size();
-                for (unsigned i=0; i<n; i++) {
+                for (unsigned i=0; i<n; ++i) {
                     result.push_back(src[permutation[i]]);
                 }
             }
@@ -587,7 +587,7 @@ namespace datalog {
                 unsigned neg_sig_size = neg_t.get_signature().size();
                 m_overlap = false;
                 m_bound.resize(neg_sig_size, false);
-                for (unsigned i=0; i<joined_col_cnt; i++) {
+                for (unsigned i=0; i<joined_col_cnt; ++i) {
                     if (m_bound[negated_cols[i]]) {
                         m_overlap = true;
                     }
@@ -607,13 +607,13 @@ namespace datalog {
             void make_neg_bindings(T & tgt_neg, const U & src) const {
                 SASSERT(m_all_neg_bound);
                 SASSERT(!m_overlap);
-                for (unsigned i=0; i<m_joined_col_cnt; i++) {
+                for (unsigned i=0; i<m_joined_col_cnt; ++i) {
                     tgt_neg[m_cols2[i]]=src[m_cols1[i]];
                 }
             }
             template<typename T, typename U>
             bool bindings_match(const T & tgt_neg, const U & src) const {
-                for (unsigned i=0; i<m_joined_col_cnt; i++) {
+                for (unsigned i=0; i<m_joined_col_cnt; ++i) {
                     if (tgt_neg[m_cols2[i]]!=src[m_cols1[i]]) {
                         return false;
                     }
@@ -984,7 +984,7 @@ namespace datalog {
 #if Z3DEBUG
             unsigned first_src_fun = src.size()-src.functional_columns();
             bool in_func = permutation_cycle[0]>=first_src_fun;
-            for (unsigned i=1;i<cycle_len;i++) {
+            for (unsigned i=1;i<cycle_len;++i) {
                 SASSERT(in_func == (permutation_cycle[i]>=first_src_fun));
             }
 #endif
@@ -1002,7 +1002,7 @@ namespace datalog {
 #if Z3DEBUG
             unsigned sz = src.size();
             unsigned first_src_fun = sz-src.functional_columns();
-            for (unsigned i=first_src_fun;i<sz;i++) {
+            for (unsigned i=first_src_fun;i<sz;++i) {
                 SASSERT(permutation[i]>=first_src_fun);
             }
 #endif
