@@ -240,7 +240,7 @@ namespace datalog {
         }
         else {
             unsigned_vector removed_cols;
-            for(unsigned i=0; i<src_col_cnt; i++) {
+            for(unsigned i=0; i<src_col_cnt; ++i) {
                 if(i!=col) {
                     removed_cols.push_back(i);
                 }
@@ -292,7 +292,7 @@ namespace datalog {
 
         //first remove unused source columns
         int_set referenced_src_cols;
-        for(unsigned i=0; i<col_cnt; i++) {
+        for(unsigned i=0; i<col_cnt; ++i) {
             if(acis[i].kind==ACK_BOUND_VAR) {
                 SASSERT(acis[i].source_column<src_col_cnt); //we refer only to existing columns
                 referenced_src_cols.insert(acis[i].source_column);
@@ -304,7 +304,7 @@ namespace datalog {
         unsigned_vector new_src_col_offset;
 
         unsigned_vector src_cols_to_remove;
-        for(unsigned i=0; i<src_col_cnt; i++) {
+        for(unsigned i=0; i<src_col_cnt; ++i) {
             if(!referenced_src_cols.contains(i)) {
                 src_cols_to_remove.push_back(i);
             }
@@ -316,7 +316,7 @@ namespace datalog {
             curr_sig = & m_reg_signatures[curr];
 
             //update ACK_BOUND_VAR references
-            for(unsigned i=0; i<col_cnt; i++) {
+            for(unsigned i=0; i<col_cnt; ++i) {
                 if(acis[i].kind==ACK_BOUND_VAR) {
                     unsigned col = acis[i].source_column;
                     acis[i].source_column = col-new_src_col_offset[col];
@@ -325,7 +325,7 @@ namespace datalog {
         }
 
         //convert all result columns into bound variables by extending the source table
-        for(unsigned i=0; i<col_cnt; i++) {
+        for(unsigned i=0; i<col_cnt; ++i) {
             if(acis[i].kind==ACK_BOUND_VAR) {
                 continue;
             }
@@ -352,7 +352,7 @@ namespace datalog {
 
         //duplicate needed source columns
         int_set used_cols;
-        for(unsigned i=0; i<col_cnt; i++) {
+        for(unsigned i=0; i<col_cnt; ++i) {
             SASSERT(acis[i].kind==ACK_BOUND_VAR);
             unsigned col=acis[i].source_column;
             if(!used_cols.contains(col)) {
@@ -369,7 +369,7 @@ namespace datalog {
 
         //reorder source columns to match target
         SASSERT(curr_sig->size()==col_cnt); //now the intermediate table is a permutation
-        for(unsigned i=0; i<col_cnt; i++) {
+        for(unsigned i=0; i<col_cnt; ++i) {
             if(acis[i].source_column==i) {
                 continue;
             }
@@ -404,7 +404,7 @@ namespace datalog {
             unsigned_vector & res) {
         // TODO: this can be optimized to avoid renames in some cases
         unsigned n = t->get_num_args();
-        for(unsigned i = 0; i<n; i++) {
+        for(unsigned i = 0; i<n; ++i) {
             expr * e = t->get_arg(i);
             if (is_var(e) && globals.get(to_var(e)->get_idx()) > 0) {
               globals.update(to_var(e)->get_idx(), -1);
@@ -427,9 +427,8 @@ namespace datalog {
             counter_tail.count_vars(r->get_tail(i));
           }
 
-          rule_counter::iterator I = counter_tail.begin(), E = counter_tail.end();
-          for (; I != E; ++I) {
-            int& n = counter.get(I->m_key);
+          for (auto const& kv : counter_tail) {
+            int& n = counter.get(kv.m_key);
             if (n == 0)
               n = -1;
           }
@@ -495,7 +494,7 @@ namespace datalog {
             unsigned rem_index = 0;
             unsigned rem_sz = removed_cols.size();
             unsigned a1len=a1->get_num_args();
-            for(unsigned i=0; i<a1len; i++) {
+            for(unsigned i=0; i<a1len; ++i) {
                 SASSERT(rem_index==rem_sz || removed_cols[rem_index]>=i);
                 if(rem_index<rem_sz && removed_cols[rem_index]==i) {
                     rem_index++;
@@ -505,7 +504,7 @@ namespace datalog {
             }
             second_tail_arg_ofs = single_res_expr.size();
             unsigned a2len=a2->get_num_args();
-            for(unsigned i=0; i<a2len; i++) {
+            for(unsigned i=0; i<a2len; ++i) {
                 SASSERT(rem_index==rem_sz || removed_cols[rem_index]>=i+a1len);
                 if(rem_index<rem_sz && removed_cols[rem_index]==i+a1len) {
                     rem_index++;
@@ -524,7 +523,7 @@ namespace datalog {
             SASSERT(m_reg_signatures[single_res].size() == a->get_num_args());
 
             unsigned n=a->get_num_args();
-            for(unsigned i=0; i<n; i++) {
+            for(unsigned i=0; i<n; ++i) {
                 expr * arg = a->get_arg(i);
                 if(is_app(arg)) {
                     app * c = to_app(arg); //argument is a constant
@@ -557,7 +556,7 @@ namespace datalog {
             //enforce equality to constants
             unsigned srlen=single_res_expr.size();
             SASSERT((single_res==execution_context::void_register) ? (srlen==0) : (srlen==m_reg_signatures[single_res].size()));
-            for(unsigned i=0; i<srlen; i++) {
+            for(unsigned i=0; i<srlen; ++i) {
                 expr * exp = single_res_expr[i].get();
                 if(is_app(exp)) {
                     SASSERT(m_context.get_decl_util().is_numeral_ext(exp));
@@ -577,11 +576,8 @@ namespace datalog {
         }
 
         //enforce equality of columns
-        int2ints::iterator vit=var_indexes.begin();
-        int2ints::iterator vend=var_indexes.end();
-        for(; vit!=vend; ++vit) {
-            int2ints::key_data & k = *vit;
-            unsigned_vector & indexes = k.m_value;
+        for (auto& kv : var_indexes) {
+            unsigned_vector & indexes = kv.m_value;
             if(indexes.size()==1) {
                 continue;
             }
@@ -646,7 +642,7 @@ namespace datalog {
         }
 
         //enforce negative predicates
-        for (unsigned i = pt_len; i<ut_len; i++) {
+        for (unsigned i = pt_len; i<ut_len; ++i) {
             app * neg_tail = r->get_tail(i);
             func_decl * neg_pred = neg_tail->get_decl();
             variable_intersection neg_intersection(m_context.get_manager());
@@ -655,7 +651,7 @@ namespace datalog {
             unsigned_vector neg_cols(neg_intersection.size(), neg_intersection.get_cols2());
 
             unsigned neg_len = neg_tail->get_num_args();
-            for (unsigned i = 0; i<neg_len; i++) {
+            for (unsigned i = 0; i<neg_len; ++i) {
                 expr * e = neg_tail->get_arg(i);
                 if (is_var(e)) {
                     continue;
@@ -681,20 +677,19 @@ namespace datalog {
 
         // enforce interpreted tail predicates
         if (!tail.empty()) {
-            app_ref filter_cond(tail.size() == 1 ? to_app(tail.back()) : m.mk_and(tail.size(), tail.data()), m);
+            app_ref filter_cond(tail.size() == 1 ? to_app(tail.back()) : m.mk_and(tail), m);
 
             // check if there are any columns to remove
             unsigned_vector remove_columns;
             {
                 unsigned_vector var_idx_to_remove;
                 m_free_vars(r->get_head());
-                for (int2ints::iterator I = var_indexes.begin(), E = var_indexes.end();
-                    I != E; ++I) {
-                    unsigned var_idx = I->m_key;
+                for (auto const& kv : var_indexes) {
+                    unsigned var_idx = kv.m_key;
                     if (!m_free_vars.contains(var_idx)) {
-                        unsigned_vector & cols = I->m_value;
-                        for (unsigned i = 0; i < cols.size(); ++i) {
-                            remove_columns.push_back(cols[i]);
+                        unsigned_vector const& cols = kv.m_value;
+                        for (unsigned col : cols) {
+                            remove_columns.push_back(col);
                         }
                         var_idx_to_remove.push_back(var_idx);
                     }
@@ -715,9 +710,8 @@ namespace datalog {
                         }
                     }
 
-                    for (int2ints::iterator I = var_indexes.begin(), E = var_indexes.end();
-                    I != E; ++I) {
-                        unsigned_vector & cols = I->m_value;
+                    for (auto& kv : var_indexes) {
+                        unsigned_vector & cols = kv.m_value;
                         for (unsigned i = 0; i < cols.size(); ++i) {
                             cols[i] -= offsets[cols[i]];
                         }
@@ -743,7 +737,7 @@ namespace datalog {
         // since it constraints each unbound column at a time (reducing the
         // size of intermediate results).
         unsigned ft_len=r->get_tail_size(); //full tail
-        for(unsigned tail_index=ut_len; tail_index<ft_len; tail_index++) {
+        for(unsigned tail_index=ut_len; tail_index<ft_len; ++tail_index) {
             app * t = r->get_tail(tail_index);
             m_free_vars(t);
             
@@ -814,7 +808,7 @@ namespace datalog {
             relation_signature & head_sig = m_reg_signatures[head_reg];
             svector<assembling_column_info> head_acis;
             unsigned_vector head_src_cols;
-            for(unsigned i=0; i<head_len; i++) {
+            for(unsigned i=0; i<head_len; ++i) {
                 assembling_column_info aci;
                 aci.domain=head_sig[i];
 
@@ -895,10 +889,9 @@ namespace datalog {
             }
         }
         // add negative variables that are not in positive
-        u_map<expr*>::iterator it = neg_vars.begin(), end = neg_vars.end();
-        for (; it != end; ++it) {
-            unsigned v = it->m_key;
-            expr* e = it->m_value;
+        for (auto const& kv : neg_vars) {
+            unsigned v = kv.m_key;
+            expr* e = kv.m_value;
             if (!pos_vars.contains(v)) {
                 single_res_expr.push_back(e);
                 make_add_unbound_column(r, v, pred, single_res, e->get_sort(), single_res, dealloc, acc);
@@ -917,7 +910,7 @@ namespace datalog {
 
         svector<reg_idx> tail_regs;
         tail_delta_infos tail_deltas;
-        for(unsigned j=0;j<rule_len;j++) {
+        for(unsigned j=0;j<rule_len;++j) {
             func_decl * tail_pred = r->get_tail(j)->get_decl();
             reg_idx tail_reg = m_pred_regs.find(tail_pred);
             tail_regs.push_back(tail_reg);
@@ -1303,12 +1296,12 @@ namespace datalog {
 
 
         //load predicate data
-        for(unsigned i=0;i<rule_cnt;i++) {
+        for(unsigned i=0;i<rule_cnt;++i) {
             const rule * r = m_rule_set.get_rule(i);
             ensure_predicate_loaded(r->get_decl(), acc);
 
             unsigned rule_len = r->get_uninterpreted_tail_size();
-            for(unsigned j=0;j<rule_len;j++) {
+            for(unsigned j=0;j<rule_len;++j) {
                 ensure_predicate_loaded(r->get_tail(j)->get_decl(), acc);
             }
         }
