@@ -65,10 +65,12 @@ void sym_mux::ensure_capacity(sym_mux_entry &entry, unsigned sz) const {
     }
 }
 
-bool sym_mux::find_idx(func_decl * sym, unsigned & idx) const {
+std::optional<unsigned> sym_mux::find_idx(func_decl * sym) const {
     std::pair<sym_mux_entry *, unsigned> entry;
-    if (m_muxes.find(sym, entry)) {idx = entry.second; return true;}
-    return false;
+    if (m_muxes.find(sym, entry)) {
+        return entry.second;
+    }
+    return std::nullopt;
 }
 
 func_decl * sym_mux::find_by_decl(func_decl* fdecl, unsigned idx) const {
@@ -101,10 +103,10 @@ struct formula_checker {
         if (m_found || !is_app(e)) { return; }
 
         func_decl * sym = to_app(e)->get_decl();
-        unsigned sym_idx;
-        if (!m_parent.find_idx(sym, sym_idx)) { return; }
+        auto sym_idx = m_parent.find_idx(sym);
+        if (!sym_idx) { return; }
 
-        bool have_idx = sym_idx == m_idx;
+        bool have_idx = *sym_idx == m_idx;
         m_found = !have_idx;
     }
 
@@ -149,7 +151,7 @@ public:
         app * a = to_app(s);
         func_decl * sym = a->get_decl();
         if (!m_parent.has_index(sym, m_from_idx)) {
-            CTRACE("spacer", m_homogenous && m_parent.is_muxed(sym), tout << "not found " << mk_pp(a, m) << "\n");
+            CTRACE(spacer, m_homogenous && m_parent.is_muxed(sym), tout << "not found " << mk_pp(a, m) << "\n");
             SASSERT(!m_homogenous || !m_parent.is_muxed(sym));
             return false;
         }
