@@ -49,7 +49,7 @@ namespace datalog {
             return false;
         }
 
-        for (unsigned i = 0; i < pt_len; i++) {
+        for (unsigned i = 0; i < pt_len; ++i) {
             func_decl * tail_pred = r->get_tail(i)->get_decl();
             if (!m_total_relations.contains(tail_pred)) {
                 // this rule has a non-total predicate in the tail
@@ -58,7 +58,7 @@ namespace datalog {
         }
 
         unsigned t_len = r->get_positive_tail_size();
-        for(unsigned i = pt_len; i < t_len; i++) {
+        for(unsigned i = pt_len; i < t_len; ++i) {
             SASSERT(!r->is_neg_tail(i)); //we assume interpreted tail not to be negated
             if (!m.is_true(r->get_tail(i))) {
                 //this rule has an interpreted tail which is not constant true
@@ -69,7 +69,7 @@ namespace datalog {
         var_idx_set head_vars;
         app * head = r->get_head();
         unsigned arity = head->get_num_args();
-        for(unsigned i=0; i<arity; i++) {
+        for(unsigned i=0; i<arity; ++i) {
             expr * arg = head->get_arg(i);
             if(!is_var(arg)) { return false; }
             unsigned idx = to_var(arg)->get_idx();
@@ -100,9 +100,7 @@ namespace datalog {
         //(discovering a total relation might reveal other total relations)
         do {
             new_discovered = false;
-            rule_set::iterator rend = rules.end();
-            for(rule_set::iterator rit = rules.begin(); rit!=rend; ++rit) {
-                rule * r = *rit;
+            for (rule* r : rules) {
                 func_decl * head_pred = r->get_decl();
                 if(is_total_rule(r) && !m_total_relations.contains(head_pred)) {
                     on_discovered_total_relation(head_pred, r);
@@ -127,7 +125,7 @@ namespace datalog {
         app_ref_vector tail(m);
         bool_vector tail_neg;
 
-        for(unsigned i=0; i<u_len; i++) {
+        for(unsigned i=0; i<u_len; ++i) {
             app * tail_atom = r->get_tail(i);
             bool neg = r->is_neg_tail(i);
             if(m_total_relations.contains(tail_atom->get_decl())
@@ -158,7 +156,7 @@ namespace datalog {
         }
 
         //we just copy the interpreted part of the tail
-        for(unsigned i=u_len; i<len; i++) {
+        for(unsigned i=u_len; i<len; ++i) {
             tail.push_back(r->get_tail(i));
             tail_neg.push_back(r->is_neg_tail(i));
         }
@@ -247,7 +245,7 @@ namespace datalog {
             }
             m_context.add_model_converter(mc0);
         }
-        TRACE("dl",
+        TRACE(dl,
             tout << "original set size: "<<orig.get_num_rules()<<"\n"
                  << "reduced set size: "<<tgt.get_num_rules()<<"\n"; );
         return modified;
@@ -261,9 +259,7 @@ namespace datalog {
 
         func_decl_set const& candidate_preds = m_context.get_predicates();
 
-        func_decl_set::iterator end = candidate_preds.end();
-        for(func_decl_set::iterator it = candidate_preds.begin(); it!=end; ++it) {
-            func_decl * pred = *it;
+        for (func_decl* pred : candidate_preds) {
             unsigned rel_sz;
 
             if (m_total_relations.contains(pred)) { continue; } // already total
@@ -273,7 +269,7 @@ namespace datalog {
             if (arity > 30) { continue; }
 
             //for now we only check booleans domains
-            for(unsigned i=0; i<arity; i++) {
+            for(unsigned i=0; i<arity; ++i) {
                 if(!m.is_bool(pred->get_domain(i))) {
                     goto next_pred;
                 }
@@ -306,9 +302,7 @@ namespace datalog {
 
     void mk_subsumption_checker::collect_ground_unconditional_rule_heads(const rule_set & rules)
     {
-        rule_set::iterator rend = rules.end();
-        for(rule_set::iterator rit = rules.begin(); rit!=rend; ++rit) {
-            rule * r = *rit;
+        for (rule* r : rules) {
             func_decl * pred = r->get_decl();
 
             if(r->get_tail_size()!=0) { continue; }
@@ -316,7 +310,7 @@ namespace datalog {
 
             app * head = r->get_head();
             unsigned arity = pred->get_arity();
-            for(unsigned i=0; i<arity; i++) {
+            for(unsigned i=0; i<arity; ++i) {
                 expr * arg = head->get_arg(i);
                 if(!is_app(arg)) {
                     goto next_rule;
