@@ -21,14 +21,15 @@ Notes:
 --*/
 #pragma once
 
-#include "sat_types.h"
+#include "sat/sat_types.h"
+#include "sat/sat_clause.h"
 
 namespace sat {
     class justification;
     class clause;
 
     struct clause_eh {
-        virtual ~clause_eh() {}
+        virtual ~clause_eh() = default;
         virtual void on_clause(unsigned, literal const*, status) = 0;        
     };
 
