@@ -148,7 +148,7 @@ namespace smt {
 
     void context::display_watch_lists(std::ostream & out) const {
         unsigned s = m_watches.size();
-        for (unsigned l_idx = 0; l_idx < s; l_idx++) {
+        for (unsigned l_idx = 0; l_idx < s; ++l_idx) {
             literal l = to_literal(l_idx);
             display_watch_list(out, l);
             out << "\n";
@@ -164,7 +164,7 @@ namespace smt {
 
     void context::display_bool_var_defs(std::ostream & out) const {
         unsigned num = get_num_bool_vars();
-        for (unsigned v = 0; v < num; v++) {
+        for (unsigned v = 0; v < num; ++v) {
             expr * n = m_bool_var2expr[v];
             ast_def_ll_pp(out << v << " ", m, n, get_pp_visited(), true, false);
         }
@@ -292,7 +292,7 @@ namespace smt {
         if (!m_e_internalized_stack.empty()) {
             out << "expression -> enode:\n";
             unsigned sz = m_e_internalized_stack.size();
-            for (unsigned i = 0; i < sz; i++) {
+            for (unsigned i = 0; i < sz; ++i) {
                 expr *  n = m_e_internalized_stack.get(i);
                 out << "(#" << n->get_id() << " -> e!" << i << ") ";
             }
@@ -304,7 +304,7 @@ namespace smt {
         if (!m_b_internalized_stack.empty()) {
             out << "expression -> bool_var:\n";
             unsigned sz = m_b_internalized_stack.size();
-            for (unsigned i = 0; i < sz; i++) {
+            for (unsigned i = 0; i < sz; ++i) {
                 expr *  n  = m_b_internalized_stack.get(i);
                 bool_var v = get_bool_var_of_id(n->get_id());
                 out << "(#" << n->get_id() << " -> " << literal(v, false) << ") ";
@@ -316,7 +316,7 @@ namespace smt {
     void context::display_hot_bool_vars(std::ostream & out) const {
         out << "hot bool vars:\n";
         unsigned num = get_num_bool_vars();
-        for (bool_var v = 0; v < num; v++) {
+        for (bool_var v = 0; v < num; ++v) {
             double val = get_activity(v)/m_bvar_inc;
             if (val > 10.00) {
                 expr * n = m_b_internalized_stack.get(v);
@@ -447,7 +447,7 @@ namespace smt {
         expr_ref_vector fmls(m);
         visitor.collect(fmls);
         expr_ref n(m);
-        for (unsigned i = 0; i < num_antecedents; i++) {
+        for (unsigned i = 0; i < num_antecedents; ++i) {
             literal l = antecedents[i];
             literal2expr(l, n);
             fmls.push_back(std::move(n));
@@ -481,14 +481,14 @@ namespace smt {
         expr_ref_vector fmls(m);
         visitor.collect(fmls);
         expr_ref n(m);
-        for (unsigned i = 0; i < num_antecedents; i++) {
+        for (unsigned i = 0; i < num_antecedents; ++i) {
             literal l = antecedents[i];
             literal2expr(l, n);
             fmls.push_back(n);
         }
-        for (unsigned i = 0; i < num_eq_antecedents; i++) {
-            enode_pair const & p = eq_antecedents[i];
-            n = m.mk_eq(p.first->get_expr(), p.second->get_expr());
+        for (unsigned i = 0; i < num_eq_antecedents; ++i) {
+            auto const& [n1, n2] = eq_antecedents[i];
+            n = m.mk_eq(n1->get_expr(), n2->get_expr());
             fmls.push_back(n);
         }
         if (x && y) {
@@ -550,7 +550,7 @@ namespace smt {
             out << n->get_decl()->get_name();
             if (!n->get_decl()->private_parameters())
                 display_parameters(out, n->get_decl()->get_num_parameters(), n->get_decl()->get_parameters());
-            for (unsigned i = 0; i < num; i++) {
+            for (unsigned i = 0; i < num; ++i) {
                 expr * arg = n->get_expr()->get_arg(i);
                 if (e_internalized(arg)) {
                     enode * n = get_enode(arg)->get_root();
@@ -697,7 +697,8 @@ namespace smt {
     }
 
     std::ostream& operator<<(std::ostream& out, enode_eq_pp const& p) {
-        return out << enode_pp(p.p.first, p.ctx) << " = " << enode_pp(p.p.second, p.ctx) << "\n";
+        auto const& [n1, n2] = p.p;
+        return out << enode_pp(n1, p.ctx) << " = " << enode_pp(n2, p.ctx) << "\n";
     }
 
     void context::log_stats() {
