@@ -27,6 +27,7 @@ Revision History:
 #include "smt/theory_array.h"
 #include "smt/theory_array_full.h"
 #include "smt/theory_bv.h"
+#include "smt/theory_intblast.h"
 #include "smt/theory_datatype.h"
 #include "smt/theory_recfun.h"
 #include "smt/theory_dummy.h"
@@ -35,9 +36,9 @@ Revision History:
 #include "smt/theory_seq.h"
 #include "smt/theory_char.h"
 #include "smt/theory_special_relations.h"
+#include "smt/theory_sls.h"
 #include "smt/theory_pb.h"
 #include "smt/theory_fpa.h"
-#include "smt/theory_str.h"
 #include "smt/theory_polymorphism.h"
 
 namespace smt {
@@ -50,14 +51,14 @@ namespace smt {
     }
 
     void setup::operator()(config_mode cm) {
-        TRACE("internalize", tout << "setup " << &m_context << "\n";);
+        TRACE(internalize, tout << "setup " << &m_context << "\n";);
         SASSERT(m_context.get_scope_level() == 0);
         SASSERT(!m_already_configured);
         // if (m_params.m_mbqi && m_params.m_model_compact) {
         //    warning_msg("ignoring MODEL_COMPACT=true because it cannot be used with MBQI=true");
         //    m_params.m_model_compact = false;
         // }
-        TRACE("setup", tout << "configuring logical context, logic: " << m_logic << " " << cm << "\n";);
+        TRACE(setup, tout << "configuring logical context, logic: " << m_logic << " " << cm << "\n";);
         
         m_already_configured = true;
         
@@ -67,6 +68,7 @@ namespace smt {
         case CFG_AUTO:  setup_auto_config(); break;
         }
         setup_card();
+        setup_sls();
     }
 
     void setup::setup_default() {
@@ -139,7 +141,7 @@ namespace smt {
     void setup::setup_auto_config() {
         static_features    st(m_manager);
         IF_VERBOSE(100, verbose_stream() << "(smt.configuring)\n";);
-        TRACE("setup", tout << "setup, logic: " << m_logic << "\n";);
+        TRACE(setup, tout << "setup, logic: " << m_logic << "\n";);
         // HACK: do not collect features for QF_BV and QF_AUFBV... since they do not use them...
         if (m_logic == "QF_BV") {
             setup_QF_BV();
@@ -152,7 +154,7 @@ namespace smt {
             ptr_vector<expr> fmls;
             m_context.get_asserted_formulas(fmls);
             st.collect(fmls.size(), fmls.data());
-            TRACE("setup", st.display_primitive(tout););
+            TRACE(setup, st.display_primitive(tout););
             IF_VERBOSE(1000, st.display_primitive(verbose_stream()););
             if (m_logic == "QF_UF") 
                 setup_QF_UF(st);
@@ -231,7 +233,7 @@ namespace smt {
     void setup::setup_QF_UF(static_features const & st) {        
         check_no_arithmetic(st, "QF_UF");
         setup_QF_UF();
-        TRACE("setup",
+        TRACE(setup,
               tout << "st.m_num_theories: " << st.m_num_theories << "\n";
               tout << "st.m_num_uninterpreted_functions: " << st.m_num_uninterpreted_functions << "\n";);
     }
@@ -265,7 +267,7 @@ namespace smt {
             throw default_exception("Benchmark is not in QF_RDL (real difference logic).");
         if (st.m_has_int)
             throw default_exception("Benchmark has integer variables but it is marked as QF_RDL (real difference logic).");
-        TRACE("setup", tout << "setup_QF_RDL(st)\n";);
+        TRACE(setup, tout << "setup_QF_RDL(st)\n";);
         check_no_uninterpreted_functions(st, "QF_RDL");
         m_params.m_relevancy_lvl       = 0;
         m_params.m_arith_eq2ineq       = true;
@@ -291,11 +293,11 @@ namespace smt {
             if (m_params.m_arith_auto_config_simplex || st.m_num_uninterpreted_constants > 4 * st.m_num_bool_constants 
                 || st.m_num_ite_terms > 0 /* theory_rdl and theory_frdl do not support ite-terms */) {
                 // if (!st.m_has_rational && !m_params.m_model && st.arith_k_sum_is_small()) {
-                //   TRACE("rdl_bug", tout << "using theory_smi_arith\n";);
+                //   TRACE(rdl_bug, tout << "using theory_smi_arith\n";);
                 //    m_context.register_plugin(alloc(smt::theory_smi_arith, m_context));
                 // }
                 // else {
-                TRACE("rdl_bug", tout << "using theory_mi_arith\n";);
+                TRACE(rdl_bug, tout << "using theory_mi_arith\n";);
                 //setup_lra_arith();
                 m_context.register_plugin(alloc(smt::theory_mi_arith, m_context));
                 // }
@@ -313,7 +315,7 @@ namespace smt {
     }
 
     void setup::setup_QF_IDL() {
-        TRACE("setup", tout << "setup_QF_IDL()\n";);
+        TRACE(setup, tout << "setup_QF_IDL()\n";);
         m_params.setup_QF_IDL();
         setup_lra_arith();
     }
@@ -323,9 +325,9 @@ namespace smt {
             throw default_exception("Benchmark is not in QF_IDL (integer difference logic).");
         if (st.m_has_real)
             throw default_exception("Benchmark has real variables but it is marked as QF_IDL (integer difference logic).");
-        TRACE("setup", tout << "setup QF_IDL, m_arith_k_sum: " << st.m_arith_k_sum << " m_num_diff_terms: " << st.m_num_arith_terms << "\n";
+        TRACE(setup, tout << "setup QF_IDL, m_arith_k_sum: " << st.m_arith_k_sum << " m_num_diff_terms: " << st.m_num_arith_terms << "\n";
               st.display_primitive(tout););
-        TRACE("setup", tout << "setup_QF_IDL(st)\n";);
+        TRACE(setup, tout << "setup_QF_IDL(st)\n";);
         check_no_uninterpreted_functions(st, "QF_IDL");
         m_params.m_relevancy_lvl       = 0;
         m_params.m_arith_eq2ineq       = true;
@@ -348,7 +350,7 @@ namespace smt {
             m_params.m_random_initial_activity = IA_RANDOM;
         }
 
-        TRACE("setup", 
+        TRACE(setup, 
               tout << "RELEVANCY: " << m_params.m_relevancy_lvl << "\n";
               tout << "ARITH_EQ_BOUNDS: " << m_params.m_arith_eq_bounds << "\n";);
 
@@ -356,7 +358,7 @@ namespace smt {
             m_context.register_plugin(alloc(smt::theory_mi_arith, m_context));
         }
         else if (!m_params.m_arith_auto_config_simplex && st.is_dense()) {
-            TRACE("setup", tout << "using dense diff logic...\n";);
+            TRACE(setup, tout << "using dense diff logic...\n";);
             m_params.m_phase_selection = PS_CACHING_CONSERVATIVE;
             if (st.arith_k_sum_is_small())
                 m_context.register_plugin(alloc(smt::theory_dense_si, m_context));
@@ -366,24 +368,24 @@ namespace smt {
         }
         else {
             // if (st.arith_k_sum_is_small()) {
-            //    TRACE("setup", tout << "using small integer simplex...\n";
+            //    TRACE(setup, tout << "using small integer simplex...\n";
             //    m_context.register_plugin(alloc(smt::theory_si_arith, m_context));
             // }
             // else {
-            TRACE("setup", tout << "using big integer simplex...\n";);
+            TRACE(setup, tout << "using big integer simplex...\n";);
             m_context.register_plugin(alloc(smt::theory_i_arith, m_context));
             // }
         }
     }
 
     void setup::setup_QF_UFIDL() {
-        TRACE("setup", tout << "setup_QF_UFIDL()\n";);
+        TRACE(setup, tout << "setup_QF_UFIDL()\n";);
         m_params.setup_QF_UFIDL();
         setup_lra_arith();
     }
 
     void setup::setup_QF_UFIDL(static_features & st) {
-        TRACE("setup", tout << "setup_QF_UFIDL(st)\n";);
+        TRACE(setup, tout << "setup_QF_UFIDL(st)\n";);
         if (st.m_has_real)
             throw default_exception("Benchmark has real variables but it is marked as QF_UFIDL (uninterpreted functions and difference logic).");
         m_params.m_relevancy_lvl    = 0;
@@ -422,7 +424,7 @@ namespace smt {
     }
 
     void setup::setup_QF_LRA() {
-        TRACE("setup", tout << "setup_QF_LRA()\n";);
+        TRACE(setup, tout << "setup_QF_LRA()\n";);
         m_params.setup_QF_LRA();
         setup_lra_arith();
     }
@@ -438,14 +440,14 @@ namespace smt {
     }
 
     void setup::setup_QF_LIA() {
-        TRACE("setup", tout << "setup_QF_LIA(st)\n";);
+        TRACE(setup, tout << "setup_QF_LIA(st)\n";);
         m_params.setup_QF_LIA();
         setup_lra_arith();
     }
 
     void setup::setup_QF_LIA(static_features const & st) {
         check_no_uninterpreted_functions(st, "QF_LIA");
-        TRACE("setup", tout << "QF_LIA setup\n";);
+        TRACE(setup, tout << "QF_LIA setup\n";);
         m_params.setup_QF_LIA(st);
         setup_lra_arith();
     }
@@ -469,19 +471,19 @@ namespace smt {
     }
 
     void setup::setup_QF_BV() {
-        TRACE("setup", tout << "qf-bv\n";);
+        TRACE(setup, tout << "qf-bv\n";);
         m_params.setup_QF_BV();
-        m_context.register_plugin(alloc(smt::theory_bv, m_context));
+        setup_bv();
     }
 
     void setup::setup_QF_AUFBV() {
         m_params.setup_QF_AUFBV();
-        m_context.register_plugin(alloc(smt::theory_bv, m_context));
+        setup_bv();
         setup_arrays();
     }
 
     void setup::setup_QF_AX() {
-        TRACE("setup", tout << "QF_AX\n";);
+        TRACE(setup, tout << "QF_AX\n";);
         m_params.setup_QF_AX();
         setup_arrays();
     }
@@ -492,7 +494,7 @@ namespace smt {
     }
 
     void setup::setup_QF_AUFLIA() {
-        TRACE("QF_AUFLIA", tout << "no static features\n";);
+        TRACE(QF_AUFLIA, tout << "no static features\n";);
         m_params.setup_QF_AUFLIA();
         setup_i_arith();
         setup_arrays();
@@ -505,10 +507,10 @@ namespace smt {
     }
 
     void setup::setup_AUFLIA(bool simple_array) {
-        TRACE("setup", tout << "AUFLIA\n";);
+        TRACE(setup, tout << "AUFLIA\n";);
         m_params.setup_AUFLIA(simple_array);
-        TRACE("setup", tout << "max_eager_multipatterns: " << m_params.m_qi_max_eager_multipatterns << "\n";);
-        m_context.register_plugin(alloc(smt::theory_i_arith, m_context));
+        TRACE(setup, tout << "max_eager_multipatterns: " << m_params.m_qi_max_eager_multipatterns << "\n";);
+        setup_i_arith();
         setup_arrays();
     }
 
@@ -520,7 +522,7 @@ namespace smt {
     }
 
     void setup::setup_AUFLIRA(bool simple_array) {
-        TRACE("setup", tout << "AUFLIRA\n";);
+        TRACE(setup, tout << "AUFLIRA\n";);
         m_params.setup_AUFLIRA(simple_array);
         setup_mi_arith();
         setup_arrays(); 
@@ -558,10 +560,7 @@ namespace smt {
     }
 
     void setup::setup_QF_S() {
-        if (m_params.m_string_solver == "z3str3") {
-            setup_str();
-        }
-        else if (m_params.m_string_solver == "seq") {
+        if (m_params.m_string_solver == "seq") {
             setup_unknown();
         }
         else if (m_params.m_string_solver == "char") {
@@ -579,7 +578,7 @@ namespace smt {
             // don't register any solver.
         }
         else {
-            throw default_exception("invalid parameter for smt.string_solver, valid options are 'z3str3', 'seq', 'auto'");
+            throw default_exception("invalid parameter for smt.string_solver, valid options are 'seq', 'auto'");
         }
     }
 
@@ -647,7 +646,7 @@ namespace smt {
                     m_context.register_plugin(alloc(smt::theory_idl, m_context));
                 else
                     m_context.register_plugin(alloc(smt::theory_rdl, m_context));
-    }
+            }
             break;
         case arith_solver_id::AS_DENSE_DIFF_LOGIC:
             m_params.m_arith_eq2ineq  = true;
@@ -693,7 +692,15 @@ namespace smt {
         family_id bv_fid = m_manager.mk_family_id("bv");
         if (m_context.get_theory(bv_fid))
             return;
-        switch(m_params.m_bv_mode) {
+        switch (m_params.m_bv_solver) {
+        case 2:
+            m_context.register_plugin(alloc(smt::theory_intblast, m_context));
+            setup_lra_arith();
+            return;
+        default:
+            break;
+        }
+        switch (m_params.m_bv_mode) {
         case BS_NO_BV:
             m_context.register_plugin(alloc(smt::theory_dummy, m_context, bv_fid, "no bit-vector"));
             break;
@@ -721,12 +728,12 @@ namespace smt {
     }
 
     void setup::setup_datatypes() {
-        TRACE("datatype", tout << "registering theory datatype...\n";);
+        TRACE(datatype, tout << "registering theory datatype...\n";);
         m_context.register_plugin(alloc(theory_datatype, m_context));
     }
 
     void setup::setup_recfuns() {
-        TRACE("recfun", tout << "registering theory recfun...\n";);
+        TRACE(recfun, tout << "registering theory recfun...\n";);
         theory_recfun * th = alloc(theory_recfun, m_context);
         m_context.register_plugin(th);
     }
@@ -737,10 +744,7 @@ namespace smt {
 
     void setup::setup_seq_str(static_features const & st) {
         // check params for what to do here when it's ambiguous
-        if (m_params.m_string_solver == "z3str3") {
-            setup_str();
-        } 
-        else if (m_params.m_string_solver == "seq") {
+        if (m_params.m_string_solver == "seq") {
             setup_seq();
         } 
         else if (m_params.m_string_solver == "empty") {
@@ -749,16 +753,11 @@ namespace smt {
         else if (m_params.m_string_solver == "none") {
             // don't register any solver.
         }
-        else if (m_params.m_string_solver == "auto") {
-            if (st.m_has_seq_non_str) {
+        else if (m_params.m_string_solver == "auto") {            
                 setup_seq();
-            } 
-            else {
-                setup_str();
-            }
         } 
         else {
-            throw default_exception("invalid parameter for smt.string_solver, valid options are 'z3str3', 'seq', 'auto'");
+            throw default_exception("invalid parameter for smt.string_solver, valid options are 'seq', 'auto'");
         }
     }
 
@@ -766,16 +765,16 @@ namespace smt {
         m_context.register_plugin(alloc(theory_pb, m_context));
     }
 
+    void setup::setup_sls() {
+        if (m_params.m_sls_enable)
+            m_context.register_plugin(alloc(theory_sls, m_context));
+    }
+
     void setup::setup_fpa() {
         setup_bv();
         m_context.register_plugin(alloc(theory_fpa, m_context));
     }
 
-    void setup::setup_str() {
-        setup_arith();
-        m_context.register_plugin(alloc(theory_str, m_context, m_manager, m_params));
-    }
-
     void setup::setup_seq() {
         m_context.register_plugin(alloc(smt::theory_seq, m_context));
         setup_char();
@@ -799,7 +798,7 @@ namespace smt {
         ptr_vector<expr> fmls;
         m_context.get_asserted_formulas(fmls);
         st.collect(fmls.size(), fmls.data());
-        TRACE("setup", tout << "setup_unknown\n";);
+        TRACE(setup, tout << "setup_unknown\n";);
         setup_arith();
         setup_arrays();
         setup_bv();
@@ -810,10 +809,27 @@ namespace smt {
         setup_fpa();
         setup_special_relations();
         setup_polymorphism();
+        setup_relevancy(st);
+    }
+
+    //
+    // quantifier free problems with bit-vectors should always use relevancy = 0
+    // there are some other cases where relevancy propagation is harmful.
+    //
+    void setup::setup_relevancy(static_features& st) {
+        // the case split queue has been constructed by now.
+        // it is not safe to disable relevancy if the case split stragegy is relevancy-dependent.
+        if (m_params.m_case_split_strategy == CS_RELEVANCY || 
+            m_params.m_case_split_strategy == CS_RELEVANCY_ACTIVITY || 
+            m_params.m_case_split_strategy == CS_RELEVANCY_GOAL)
+            return;
+
+        if (st.m_has_bv && !st.m_has_fpa && st.m_num_quantifiers == 0)
+             m_params.m_relevancy_lvl = 0;           
     }
 
     void setup::setup_unknown(static_features & st) {
-        TRACE("setup", tout << "setup_unknown\n";);
+        TRACE(setup, tout << "setup_unknown\n";);
         if (st.m_num_quantifiers > 0) {
             if (st.m_has_real)
                 setup_AUFLIRA(false);
@@ -830,7 +846,7 @@ namespace smt {
             return;
         }
 
-        TRACE("setup",
+        TRACE(setup,
               tout << "num non UF theories: " << st.num_non_uf_theories() << "\n";
               tout << "num theories: " << st.num_theories() << "\n";
               tout << "is_diff_logic: " << is_diff_logic(st) << "\n";
