@@ -34,7 +34,6 @@ namespace smt {
 
     theory_array_full::~theory_array_full() {
         std::for_each(m_var_data_full.begin(), m_var_data_full.end(), delete_proc<var_data_full>());
-        m_var_data_full.reset();
     }
 
     theory* theory_array_full::mk_fresh(context* new_ctx) { 
@@ -112,7 +111,7 @@ namespace smt {
             }
             m_trail_stack.push(reset_flag_trail(d->m_prop_upward));
             d->m_prop_upward = true;
-            TRACE("array", tout << "#" << v << "\n";);
+            TRACE(array, tout << "#" << v << "\n";);
             if (!m_params.m_array_delay_exp_axiom) {
                 instantiate_axiom2b_for(v);
                 instantiate_axiom_map_for(v);
@@ -134,7 +133,7 @@ namespace smt {
     // call set_prop_upward on array arguments.
     // 
     void theory_array_full::set_prop_upward(enode * n) {
-        TRACE("array", tout << pp(n, m) << "\n";);
+        TRACE(array, tout << pp(n, m) << "\n";);
         if (is_store(n)) {
             set_prop_upward(n->get_arg(0)->get_th_var(get_id()));
         }
@@ -266,13 +265,13 @@ namespace smt {
         if (ctx.e_internalized(n)) {
             return true;
         }
-        TRACE("array", tout << mk_pp(n, m) << "\n";);
+        TRACE(array, tout << mk_pp(n, m) << "\n";);
 
         if (is_store(n) || is_select(n)) {
             return theory_array::internalize_term(n);
         }
 
-        if (!is_const(n) && !is_default(n)  && !is_map(n) && !is_as_array(n) && !is_set_has_size(n) && !is_set_card(n)) {
+        if (!is_const(n) && !is_default(n)  && !is_map(n) && !is_as_array(n)) {
             if (!is_array_ext(n))
                 found_unsupported_op(n);
             return false;
@@ -296,12 +295,6 @@ namespace smt {
                 mk_var(arg0);
             }
         }
-        else if (is_set_has_size(n) || is_set_card(n)) {
-            if (!m_bapa) {
-                m_bapa = alloc(theory_array_bapa, *this);
-            }
-            m_bapa->internalize_term(n);
-        }
 
         enode* node = ctx.get_enode(n);
         if (!is_attached_to_var(node)) {
@@ -340,6 +333,8 @@ namespace smt {
             SASSERT(n->get_num_args() == 2);
             instantiate_extensionality(ctx.get_enode(n->get_arg(0)), ctx.get_enode(n->get_arg(1)));
         }
+        if (!ctx.relevancy())
+            relevant_eh(n);
         return true;
     }
 
@@ -359,7 +354,7 @@ namespace smt {
             add_as_array(v1, n);
         for (enode* n : d2->m_lambdas)
             add_lambda(v1, n);
-        TRACE("array", 
+        TRACE(array, 
               tout << pp(get_enode(v1), m) << "\n";
               tout << pp(get_enode(v2), m) << "\n";
               tout << "merge in\n"; display_var(tout, v2);
@@ -370,7 +365,7 @@ namespace smt {
         SASSERT(v != null_theory_var);
         v = find(v);
         var_data* d = m_var_data[v];
-        TRACE("array", tout << "v" << v << " " << pp(get_enode(v), m) << " " 
+        TRACE(array, tout << "v" << v << " " << pp(get_enode(v), m) << " " 
               << d->m_prop_upward << " " << m_params.m_array_delay_exp_axiom << "\n";);
         for (enode * store : d->m_stores) {
             SASSERT(is_store(store));
@@ -383,7 +378,7 @@ namespace smt {
     }
 
     void theory_array_full::add_parent_select(theory_var v, enode * s) {
-        TRACE("array", 
+        TRACE(array, 
               tout << v << " select parent: " << pp(s, m) << "\n";
               display_var(tout, v);
               );
@@ -409,7 +404,7 @@ namespace smt {
     }
     
     void theory_array_full::relevant_eh(app* n) {
-        TRACE("array", tout << mk_pp(n, m) << "\n";);
+        TRACE(array, tout << mk_pp(n, m) << "\n";);
         theory_array::relevant_eh(n);
         if (!is_default(n) && !is_select(n) && !is_map(n) && !is_const(n) && !is_as_array(n)){
             return;
@@ -450,11 +445,10 @@ namespace smt {
     }
 
     bool theory_array_full::should_research(expr_ref_vector & unsat_core) {
-        return m_bapa && m_bapa->should_research(unsat_core);
+        return false;
     }
 
     void theory_array_full::add_theory_assumptions(expr_ref_vector & assumptions) {
-        if (m_bapa) m_bapa->add_theory_assumptions(assumptions);
     }
        
     //
@@ -470,7 +464,7 @@ namespace smt {
         func_decl* f = to_func_decl(map->get_decl()->get_parameter(0).get_ast());
 
 
-        TRACE("array_map_bug", tout << "invoked instantiate_select_map_axiom\n";
+        TRACE(array_map_bug, tout << "invoked instantiate_select_map_axiom\n";
               tout << sl->get_owner_id() << " " << mp->get_owner_id() << "\n";
               tout << mk_ismt2_pp(sl->get_expr(), m) << "\n" << mk_ismt2_pp(mp->get_expr(), m) << "\n";);
 
@@ -478,10 +472,10 @@ namespace smt {
             return false;
         }
 
-        TRACE("array_map_bug", tout << "new axiom\n";);
+        TRACE(array_map_bug, tout << "new axiom\n";);
 
         m_stats.m_num_map_axiom++;
-        TRACE("array", 
+        TRACE(array, 
               tout << mk_bounded_pp(mp->get_expr(), m) << "\n";
               tout << mk_bounded_pp(sl->get_expr(), m) << "\n";);
         unsigned num_args   = select->get_num_args();
@@ -513,7 +507,7 @@ namespace smt {
         ctx.internalize(sel1, false);
         ctx.internalize(sel2, false);
         
-        TRACE("array_map_bug",
+        TRACE(array_map_bug,
               tout << "select-map axiom\n" << mk_ismt2_pp(sel1, m) << "\n=\n" << mk_ismt2_pp(sel2,m) << "\n";);
 
         return try_assign_eq(sel1, sel2);
@@ -533,7 +527,7 @@ namespace smt {
         if (!ctx.add_fingerprint(this, m_default_map_fingerprint, 1, &mp)) {
             return false;
         }
-        TRACE("array", tout << mk_bounded_pp(map, m) << "\n";);
+        TRACE(array, tout << mk_bounded_pp(map, m) << "\n";);
 
         m_stats.m_num_default_map_axiom++;
 
@@ -559,7 +553,7 @@ namespace smt {
         }
         m_stats.m_num_default_const_axiom++;
         SASSERT(is_const(cnst));
-        TRACE("array", tout << mk_bounded_pp(cnst->get_expr(), m) << "\n";);
+        TRACE(array, tout << mk_bounded_pp(cnst->get_expr(), m) << "\n";);
         expr* val = cnst->get_arg(0)->get_expr();
         expr_ref def(mk_default(cnst->get_expr()), m);
         ctx.internalize(def, false);
@@ -573,24 +567,6 @@ namespace smt {
 
     bool theory_array_full::instantiate_default_as_array_axiom(enode* arr) {
         return false;
-#if 0
-        if (!ctx.add_fingerprint(this, m_default_as_array_fingerprint, 1, &arr)) {
-            return false;
-        }
-        m_stats.m_num_default_as_array_axiom++;
-        SASSERT(is_as_array(arr));
-        TRACE("array", tout << mk_bounded_pp(arr->get_owner(), m) << "\n";);
-        expr* def = mk_default(arr->get_owner());
-        func_decl * f = array_util(m).get_as_array_func_decl(arr->get_owner());
-        ptr_vector<expr> args;
-        for (unsigned i = 0; i < f->get_arity(); ++i) {
-            args.push_back(mk_epsilon(f->get_domain(i)));
-        }
-        expr_ref val(m.mk_app(f, args.size(), args.c_ptr()), m);
-        ctx.internalize(def, false);
-        ctx.internalize(val.get(), false);
-        return try_assign_eq(val.get(), def);
-#endif
     }
 
     bool theory_array_full::instantiate_default_lambda_def_axiom(enode* arr) {
@@ -600,7 +576,7 @@ namespace smt {
         expr* e = arr->get_expr();
         expr_ref def(mk_default(e), m);
         quantifier* lam = m.is_lambda_def(arr->get_decl());
-        TRACE("array", tout << mk_pp(lam, m) << "\n" << mk_pp(e, m) << "\n");
+        TRACE(array, tout << mk_pp(lam, m) << "\n" << mk_pp(e, m) << "\n");
         expr_ref_vector args(m);       
         var_subst subst(m, false);
         args.push_back(subst(lam, to_app(e)->get_num_args(), to_app(e)->get_args()));
@@ -620,41 +596,6 @@ namespace smt {
         return try_assign_eq(val.get(), def);
     }
 
-
-    bool theory_array_full::has_unitary_domain(app* array_term) {
-        SASSERT(is_array_sort(array_term));
-        sort* s = array_term->get_sort();
-        unsigned dim = get_dimension(s);
-        parameter const * params = s->get_info()->get_parameters();
-        for (unsigned i = 0; i < dim; ++i) {
-            SASSERT(params[i].is_ast());
-            sort* d = to_sort(params[i].get_ast());
-            if (d->is_infinite() || d->is_very_big() || 1 != d->get_num_elements().size())
-                return false;
-        }
-        return true;        
-    }
-
-   bool theory_array_full::has_large_domain(app* array_term) {
-        SASSERT(is_array_sort(array_term));
-        sort* s = array_term->get_sort();
-        unsigned dim = get_dimension(s);
-        parameter const *  params = s->get_info()->get_parameters();
-        rational sz(1);
-        for (unsigned i = 0; i < dim; ++i) {
-            SASSERT(params[i].is_ast());
-            sort* d = to_sort(params[i].get_ast());
-            if (d->is_infinite() || d->is_very_big()) {
-                return true;
-            }
-            sz *= rational(d->get_num_elements().size(),rational::ui64());
-            if (sz >= rational(1 << 14)) {
-                return true;
-            }
-        }
-        return false;        
-    }
-
     //
     // Assert axiom:
     // select(const v, i_1, ..., i_n) = v
@@ -676,7 +617,7 @@ namespace smt {
         }
         expr * sel = mk_select(sel_args.size(), sel_args.data());
         expr * val = cnst->get_expr()->get_arg(0);
-        TRACE("array", tout << "new select-const axiom...\n";
+        TRACE(array, tout << "new select-const axiom...\n";
               tout << "const: " << mk_bounded_pp(cnst->get_expr(), m) << "\n";
               tout << "select: " << mk_bounded_pp(select->get_expr(), m) << "\n";
               tout << " sel/const: " << mk_bounded_pp(sel, m) << "\n";
@@ -711,7 +652,7 @@ namespace smt {
         expr * sel = mk_select(sel_args.size(), sel_args.data());
         func_decl * f = array_util(m).get_as_array_func_decl(arr->get_expr());
         expr_ref val(m.mk_app(f, sel_args.size()-1, sel_args.data()+1), m);
-        TRACE("array", tout << "new select-as-array axiom...\n";
+        TRACE(array, tout << "new select-as-array axiom...\n";
               tout << "as-array: " << mk_bounded_pp(arr->get_expr(), m) << "\n";
               tout << "select: " << mk_bounded_pp(select->get_expr(), m) << "\n";
               tout << " sel/as-array: " << mk_bounded_pp(sel, m) << "\n";
@@ -737,7 +678,7 @@ namespace smt {
 
         expr_ref def1(m), def2(m);
 
-        TRACE("array", tout << mk_bounded_pp(store_app, m) << "\n";);
+        TRACE(array, tout << mk_bounded_pp(store_app, m) << "\n";);
 
         unsigned num_args = store_app->get_num_args();
 
@@ -745,11 +686,12 @@ namespace smt {
         def2 = mk_default(store_app->get_arg(0));
 
         bool is_new = false;
+        rational sz;
 
         if (has_unitary_domain(store_app)) {
             def2 = store_app->get_arg(num_args - 1);
         }        
-        else if (!has_large_domain(store_app)) {
+        else if (!has_large_domain(store_app, sz)) {
             //
             // let A = store(B, i, v)
             // 
@@ -758,16 +700,20 @@ namespace smt {
             //  default(B) = B[epsilon]
             //
             //
-            expr_ref_vector args1(m), args2(m);
+            expr_ref_vector args1(m), args2(m), args3(m), args4(m);
             args1.push_back(store_app);
             args2.push_back(store_app->get_arg(0));
+            args3.push_back(store_app);
+            args4.push_back(store_app->get_arg(0));
 
             for (unsigned i = 1; i + 1 < num_args; ++i) {
                 expr* arg = store_app->get_arg(i);
                 sort* srt = arg->get_sort();
-                auto ep = mk_epsilon(srt);
-                args1.push_back(ep.first);
-                args2.push_back(ep.first);
+                auto [ep, diag] = mk_epsilon(srt);
+                args1.push_back(ep);
+                args2.push_back(ep);
+                args3.push_back(m.mk_app(diag, arg));
+                args4.push_back(m.mk_app(diag, arg));
             }            
             app_ref sel1(m), sel2(m);
             sel1 = mk_select(args1);
@@ -775,6 +721,10 @@ namespace smt {
             ctx.internalize(def1, false);
             ctx.internalize(def2, false);
             is_new = try_assign_eq(def1, sel1) || try_assign_eq(def2, sel2);
+            sel1 = mk_select(args3);
+            sel2 = mk_select(args4);
+            is_new = try_assign_eq(sel1, sel2) || is_new;
+            
             return is_new;
         }
 
@@ -783,18 +733,18 @@ namespace smt {
         return try_assign_eq(def1, def2) || is_new;
     }
 
-    std::pair<app*,func_decl*> theory_array_full::mk_epsilon(sort* s) {
-        app* eps = nullptr;
-        func_decl* diag = nullptr;
+    std::pair<app *, func_decl *> theory_array_full::mk_epsilon(sort *s) {
+        app *eps = nullptr;
+        func_decl *diag = nullptr;
         if (!m_sort2epsilon.find(s, eps)) {
             eps = m.mk_fresh_const("epsilon", s);
-            m_trail_stack.push(ast2ast_trail<sort, app>(m_sort2epsilon, s, eps));   
+            m_trail_stack.push(ast2ast_trail<sort, app>(m_sort2epsilon, s, eps));
         }
         if (!m_sort2diag.find(s, diag)) {
             diag = m.mk_fresh_func_decl("diag", 1, &s, s);
-            m_trail_stack.push(ast2ast_trail<sort, func_decl>(m_sort2diag, s, diag));   
+            m_trail_stack.push(ast2ast_trail<sort, func_decl>(m_sort2diag, s, diag));
         }
-        return std::make_pair(eps, diag);
+        return {eps, diag};
     }
 
     final_check_status theory_array_full::assert_delayed_axioms() {        
@@ -805,7 +755,7 @@ namespace smt {
         else { 
             r = theory_array::assert_delayed_axioms();
             unsigned num_vars = get_num_vars();
-            for (unsigned v = 0; v < num_vars; v++) {
+            for (unsigned v = 0; v < num_vars; ++v) {
                 var_data * d = m_var_data[v];
                 if (d->m_prop_upward && instantiate_axiom_map_for(v))
                     r = FC_CONTINUE;
@@ -815,9 +765,6 @@ namespace smt {
                 }
             }
         }
-        if (r == FC_DONE && m_bapa) {
-            r = m_bapa->final_check();
-        }
         bool should_giveup = m_found_unsupported_op || has_propagate_up_trail() || has_non_beta_as_array();
         if (r == FC_DONE && should_giveup)
             r = FC_GIVEUP;
@@ -827,15 +774,15 @@ namespace smt {
     bool theory_array_full::has_non_beta_as_array() {
         for (enode* n : m_as_array) {
             for (enode* p : n->get_parents())
-                if (!ctx.is_beta_redex(p, n)) {
-                    TRACE("array", tout << "not a beta redex " << enode_pp(p, ctx) << "\n");
+                if (ctx.is_relevant(p) && !ctx.is_beta_redex(p, n)) {
+                    TRACE(array, tout << "not a beta redex " << enode_pp(p, ctx) << "\n");
                     return true;
                 }
         }
         for (enode* n : m_lambdas) 
             for (enode* p : n->get_parents())
-                if (!is_default(p) && !ctx.is_beta_redex(p, n)) {
-                    TRACE("array", tout << "lambda is not a beta redex " << enode_pp(p, ctx) << "\n");
+                if (ctx.is_relevant(p) && !is_default(p) && !ctx.is_beta_redex(p, n)) {
+                    TRACE(array, tout << "lambda is not a beta redex " << enode_pp(p, ctx) << "\n");
                     return true;
                 }
         return false;
@@ -844,7 +791,7 @@ namespace smt {
 
     bool theory_array_full::instantiate_parent_stores_default(theory_var v) {
         SASSERT(v != null_theory_var);
-        TRACE("array", tout << "v" << v << "\n";);
+        TRACE(array, tout << "v" << v << "\n";);
         v = find(v);
         var_data* d = m_var_data[v];
         bool result = false;
@@ -860,7 +807,7 @@ namespace smt {
     }
 
     bool theory_array_full::try_assign_eq(expr* v1, expr* v2) {
-        TRACE("array", tout << mk_bounded_pp(v1, m) << "\n==\n" << mk_bounded_pp(v2, m) << "\n";);
+        TRACE(array, tout << mk_bounded_pp(v1, m) << "\n==\n" << mk_bounded_pp(v2, m) << "\n";);
         
         if (m_eqs.contains(v1, v2)) {
             return false;
