@@ -20,10 +20,11 @@ Revision History:
 
 #include "util/union_find.h"
 #include "ast/array_decl_plugin.h"
+#include "ast/seq_decl_plugin.h"
 #include "ast/datatype_decl_plugin.h"
 #include "model/datatype_factory.h"
 #include "smt/smt_theory.h"
-#include "smt/params/theory_datatype_params.h"
+#include "params/theory_datatype_params.h"
 
 namespace smt {
     class theory_datatype : public theory {
@@ -32,6 +33,18 @@ namespace smt {
         struct var_data {
             ptr_vector<enode> m_recognizers; //!< recognizers of this equivalence class that are being watched.
             enode *           m_constructor; //!< constructor of this equivalence class, 0 if there is no constructor in the eqc.
+
+            /**
+             *  \brief subterm predicates that involve this equivalence class
+             * 
+             * So all terms of the shape `a ⊑ b` where `var_data` represents either `a` or `b`.
+             * 
+             * This is more a set than a vector, but I'll use `ptr_vector`
+             * because I know the API better, it's easier to backtrack on it and
+             * it should be small enough to outperform a hasmap anyway
+            */
+            ptr_vector<enode> m_subterms;
+
             var_data():
                 m_constructor(nullptr) {
             }
@@ -46,6 +59,7 @@ namespace smt {
         
         datatype_util             m_util;
         array_util                m_autil;
+        seq_util                  m_sutil;
         ptr_vector<var_data>      m_var_data;
         th_union_find             m_find;
         trail_stack               m_trail_stack;
@@ -54,11 +68,13 @@ namespace smt {
 
         bool is_constructor(app * f) const { return m_util.is_constructor(f); }
         bool is_recognizer(app * f) const { return m_util.is_recognizer(f); }
+        bool is_subterm_predicate(app * f) const { return m_util.is_subterm_predicate(f); }
         bool is_accessor(app * f) const { return m_util.is_accessor(f); }
         bool is_update_field(app * f) const { return m_util.is_update_field(f); }
 
         bool is_constructor(enode * n) const { return is_constructor(n->get_expr()); }
         bool is_recognizer(enode * n) const { return is_recognizer(n->get_expr()); }
+        bool is_subterm_predicate(enode * n) const { return is_subterm_predicate(n->get_expr()); }
         bool is_accessor(enode * n) const { return is_accessor(n->get_expr()); }
         bool is_update_field(enode * n) const { return m_util.is_update_field(n->get_expr()); }
 
@@ -66,8 +82,15 @@ namespace smt {
         void assert_is_constructor_axiom(enode * n, func_decl * c, literal antecedent);
         void assert_accessor_axioms(enode * n);
         void assert_update_field_axioms(enode * n);
+        void assert_subterm_axioms(enode * n);
         void add_recognizer(theory_var v, enode * recognizer);
-        void propagate_recognizer(theory_var v, enode * r);
+        void add_subterm_predicate(theory_var v, enode *predicate);
+        void propagate_subterm(enode * n, bool is_true);
+        void propagate_is_subterm(enode * n);
+        void propagate_not_is_subterm(enode *n);
+        void split_leaf_root(smt::enode *arg2);
+        void propagate_subterm_with_constructor(theory_var v);
+        void propagate_recognizer(theory_var v, enode *r);
         void sign_recognizer_conflict(enode * c, enode * r);
 
         typedef enum { ENTER, EXIT } stack_op;
@@ -90,8 +113,9 @@ namespace smt {
         bool oc_cycle_free(enode * n) const { return n->get_root()->is_marked2(); }
 
         void oc_push_stack(enode * n);
-        ptr_vector<enode> m_array_args;
+        ptr_vector<enode> m_args, m_todo;
         ptr_vector<enode> const& get_array_args(enode* n);
+        ptr_vector<enode> const& get_seq_args(enode* n, enode*& sibling);
 
         // class for managing state of final_check
         class final_check_st {
@@ -110,6 +134,7 @@ namespace smt {
         void mk_split(theory_var v);
 
         void display_var(std::ostream & out, theory_var v) const;
+        ptr_vector<enode> list_subterms(enode* arg);
 
     protected:
         theory_var mk_var(enode * n) override;
@@ -123,11 +148,54 @@ namespace smt {
         void relevant_eh(app * n) override;
         void push_scope_eh() override;
         void pop_scope_eh(unsigned num_scopes) override;
-        final_check_status final_check_eh() override;
+        final_check_status final_check_eh(unsigned) override;
         void reset_eh() override;
         void restart_eh() override { m_util.reset(); }
         bool is_shared(theory_var v) const override;
         theory_datatype_params const& params() const;
+        struct iterator_factory;
+        struct subterm_iterator {
+            iterator_factory &f;
+            ptr_vector<enode> m_todo;
+            enode *m_current = nullptr;
+
+            void next();
+
+            bool operator!=(const subterm_iterator &other) const { return m_current != other.m_current; }
+
+            enode *operator*() const { return m_current; }
+
+            void operator++() { next(); }
+
+            subterm_iterator(iterator_factory &f, enode *start) : f(f) {
+                if (start) {
+                    m_todo.push_back(start);
+                    next();
+                }
+            }
+        };
+
+        struct iterator_factory {
+            theory_datatype &th;
+            ptr_vector<enode> m_marked;
+            enode *start;
+            iterator_factory(theory_datatype &th, enode* start) : th(th), start(start) {}
+            subterm_iterator begin() {
+                return subterm_iterator(*this, start);
+            }
+            subterm_iterator end() {
+                return subterm_iterator(*this, nullptr);
+            }
+            void reset() {
+                for (enode* n : m_marked) 
+                    n->unset_mark();                
+                m_marked.reset();
+            }
+        };
+
+        iterator_factory iterate_subterms(enode *arg) {
+            return iterator_factory(*this, arg);
+        }
     public:
         theory_datatype(context& ctx);
         ~theory_datatype() override;
@@ -144,7 +212,6 @@ namespace smt {
         bool include_func_interp(func_decl* f) override;
 
     };
-
 };
 
 
