@@ -38,7 +38,7 @@ namespace smt {
         bool use_diseqs() const override;
         void new_diseq_eh(theory_var v1, theory_var v2) override;
         void reset_eh() override;
-        final_check_status final_check_eh() override;
+        final_check_status final_check_eh(unsigned) override;
         bool build_models() const override {
             return false;
         }
@@ -46,7 +46,6 @@ namespace smt {
 
     public:
         theory_dummy(context& ctx, family_id fid, char const * name);
-        ~theory_dummy() override {}
 
         theory * mk_fresh(context * new_ctx) override { return alloc(theory_dummy, *new_ctx, get_family_id(), m_name); }
 
