@@ -131,6 +131,7 @@ namespace smt {
         special_relations_util         m_util;
         atoms                          m_atoms;
         unsigned_vector                m_atoms_lim;
+        ptr_vector<app>                m_terms;
         obj_map<func_decl, relation*>  m_relations;
         bool_var2atom                  m_bool_var2atom;
         bool                           m_can_propagate;
@@ -186,7 +187,7 @@ namespace smt {
         void new_diseq_eh(theory_var v1, theory_var v2) override {}
         bool use_diseqs() const override { return false; }
         bool build_models() const override { return true; }
-        final_check_status final_check_eh() override;
+        final_check_status final_check_eh(unsigned) override;
         void reset_eh() override;
         void assign_eh(bool_var v, bool is_true) override;
         void init_search_eh() override {}
@@ -199,6 +200,8 @@ namespace smt {
         bool can_propagate() override { return m_can_propagate; }
         void propagate() override;
         void display(std::ostream & out) const override;
+
+        void get_specrels(func_decl_set& rels) const;
    
     };
 }
