@@ -59,7 +59,7 @@ class factor_tactic : public tactic {
         void mk_eq(polynomial::factors const & fs, expr_ref & result) {
             expr_ref_buffer args(m);
             expr_ref arg(m);
-            for (unsigned i = 0; i < fs.distinct_factors(); i++) {
+            for (unsigned i = 0; i < fs.distinct_factors(); ++i) {
                 m_expr2poly.to_expr(fs[i], true, arg);
                 args.push_back(arg);
             }
@@ -70,14 +70,14 @@ class factor_tactic : public tactic {
         void mk_split_eq(polynomial::factors const & fs, expr_ref & result) {
             expr_ref_buffer args(m);
             expr_ref arg(m);
-            for (unsigned i = 0; i < fs.distinct_factors(); i++) {
+            for (unsigned i = 0; i < fs.distinct_factors(); ++i) {
                 m_expr2poly.to_expr(fs[i], true, arg);
                 args.push_back(m.mk_eq(arg, mk_zero_for(arg)));
             }
             if (args.size() == 1)
                 result = args[0];
             else
-                result = m.mk_or(args.size(), args.data());
+                result = m.mk_or(args);
         }
 
         decl_kind flip(decl_kind k) {
@@ -100,7 +100,7 @@ class factor_tactic : public tactic {
             SASSERT(k == OP_LT || k == OP_GT || k == OP_LE || k == OP_GE);
             expr_ref_buffer args(m);
             expr_ref arg(m);
-            for (unsigned i = 0; i < fs.distinct_factors(); i++) {
+            for (unsigned i = 0; i < fs.distinct_factors(); ++i) {
                 m_expr2poly.to_expr(fs[i], true, arg);
                 if (fs.get_degree(i) % 2 == 0)
                     arg = m_util.mk_power(arg, m_util.mk_numeral(rational(2), m_util.is_int(arg)));
@@ -113,7 +113,7 @@ class factor_tactic : public tactic {
         // See mk_split_strict_comp and mk_split_nonstrict_comp
         void split_even_odd(bool strict, polynomial::factors const & fs, expr_ref_buffer & even_eqs, expr_ref_buffer & odd_factors) {
             expr_ref arg(m);
-            for (unsigned i = 0; i < fs.distinct_factors(); i++) {
+            for (unsigned i = 0; i < fs.distinct_factors(); ++i) {
                 m_expr2poly.to_expr(fs[i], true, arg);
                 if (fs.get_degree(i) % 2 == 0) {
                     expr * eq = m.mk_eq(arg, mk_zero_for(arg));
@@ -161,9 +161,9 @@ class factor_tactic : public tactic {
             if (args.size() == 1)
                 result = args[0];
             else if (strict)
-                result = m.mk_and(args.size(), args.data());
+                result = m.mk_and(args);
             else
-                result = m.mk_or(args.size(), args.data());
+                result = m.mk_or(args);
         }
 
         br_status factor(func_decl * f, expr * lhs, expr * rhs, expr_ref & result) {
@@ -173,7 +173,7 @@ class factor_tactic : public tactic {
             scoped_mpz d2(m_qm);
             m_expr2poly.to_polynomial(lhs, p1, d1);
             m_expr2poly.to_polynomial(rhs, p2, d2);
-            TRACE("factor_tactic_bug",
+            TRACE(factor_tactic_bug,
                   tout << "lhs: " << mk_ismt2_pp(lhs, m) << "\n";
                   tout << "p1:  " << p1 << "\n";
                   tout << "d1:  " << d1 << "\n";
@@ -190,10 +190,10 @@ class factor_tactic : public tactic {
             if (is_const(p))
                 return BR_FAILED;
             polynomial::factors fs(m_pm);
-            TRACE("factor_tactic_bug", tout << "p: " << p << "\n";);
+            TRACE(factor_tactic_bug, tout << "p: " << p << "\n";);
             m_pm.factor(p, fs, m_fparams);
             SASSERT(fs.distinct_factors() > 0);
-            TRACE("factor_tactic_bug", tout << "factors:\n"; fs.display(tout); tout << "\n";);
+            TRACE(factor_tactic_bug, tout << "factors:\n"; fs.display(tout); tout << "\n";);
             if (fs.distinct_factors() == 1 && fs.get_degree(0) == 1)
                 return BR_FAILED;
             if (m.is_eq(f)) {
@@ -264,7 +264,7 @@ class factor_tactic : public tactic {
             expr_ref   new_curr(m);
             proof_ref  new_pr(m);
             unsigned   size = g->size();
-            for (unsigned idx = 0; !g->inconsistent() && idx < size; idx++) {
+            for (unsigned idx = 0; !g->inconsistent() && idx < size; ++idx) {
                 expr * curr = g->form(idx);
                 m_rw(curr, new_curr, new_pr);
                 if (produce_proofs) {
@@ -316,7 +316,7 @@ public:
             throw ex;
         }
         catch (z3_exception & ex) {
-            throw tactic_exception(ex.msg());
+            throw tactic_exception(ex.what());
         }
     }
 
