@@ -3,18 +3,30 @@ Copyright (c) 2015 Microsoft Corporation
 
 Module Name:
 
-    bvarray2ufbvarray2uf_tactic.h
-
-Abstract:
-
-    Tactic that rewrites bit-vector arrays into bit-vector
-    (uninterpreted) functions.
+    bvarray2uf_tactic.h
 
 Author:
 
     Christoph (cwinter) 2015-11-04
 
-Notes:
+Tactic Documentation:
+
+## Tactic bvarray2uf
+
+### Short Description
+
+Tactic that rewrites bit-vector arrays into bit-vector
+(uninterpreted) functions.
+
+### Example
+
+```z3
+(declare-const a (Array (_ BitVec 32) (_ BitVec 32)))
+(declare-const b (_ BitVec 32))
+(declare-const c (_ BitVec 32))
+(assert (= (select a b) c))
+(apply bvarray2uf)
+```
 
 --*/
 #pragma once
