@@ -20,7 +20,7 @@ Notes:
 #include "tactic/tactical.h"
 #include "ast/normal_forms/defined_names.h"
 #include "ast/rewriter/rewriter_def.h"
-#include "tactic/generic_model_converter.h"
+#include "ast/converters/generic_model_converter.h"
 
 class elim_term_ite_tactic : public tactic {
 
@@ -108,7 +108,7 @@ class elim_term_ite_tactic : public tactic {
             expr_ref   new_curr(m);
             proof_ref  new_pr(m);
             unsigned   size = g->size();
-            for (unsigned idx = 0; idx < size; idx++) {
+            for (unsigned idx = 0; idx < size; ++idx) {
                 expr * curr = g->form(idx);
                 m_rw(curr, new_curr, new_pr);
                 if (produce_proofs) {
@@ -143,8 +143,8 @@ public:
     }
 
     void updt_params(params_ref const & p) override {
-        m_params = p;
-        m_imp->m_rw.cfg().updt_params(p);
+        m_params.append(p);
+        m_imp->m_rw.cfg().updt_params(m_params);
     }
 
     void collect_param_descrs(param_descrs & r) override {
