@@ -62,45 +62,14 @@ Notes:
    where f_1_2, f_1_3 and f_2_3 are new function symbols.
    Using the new map, we can replace the occurrences of f.
 */
+namespace {
+
 class reduce_args_tactic : public tactic {
-    struct     imp;
-    imp *      m_imp;
-
-public:
-    reduce_args_tactic(ast_manager & m);
-
-    tactic * translate(ast_manager & m) override {
-        return alloc(reduce_args_tactic, m);
-    }
-
-    ~reduce_args_tactic() override;
-
-    char const* name() const override { return "reduce_args"; }
-    
-    void operator()(goal_ref const & g, goal_ref_buffer & result) override;
-    void cleanup() override;
-    void user_propagate_register_expr(expr* e) override;
-    void user_propagate_clear() override;
-};
-
-tactic * mk_reduce_args_tactic(ast_manager & m, params_ref const & p) {
-    return clean(alloc(reduce_args_tactic, m));
-}
-
-struct reduce_args_tactic::imp {
-    expr_ref_vector m_vars;
+    expr_ref_vector          m_vars;
     ast_manager &            m;
     bv_util                  m_bv;
     array_util               m_ar;
 
-    
-    imp(ast_manager & m):
-        m_vars(m),
-        m(m),
-        m_bv(m),
-        m_ar(m) {
-    }
-
     static bool is_var_plus_offset(ast_manager& m, bv_util& bv, expr* e, expr*& base) {
         expr *lhs, *rhs;
         if (bv.is_bv_add(e, lhs, rhs) && bv.is_numeral(lhs)) {
@@ -177,12 +146,12 @@ struct reduce_args_tactic::imp {
         find_non_candidates_proc proc(m, m_bv, m_ar, non_candidates);
         expr_fast_mark1 visited;
         unsigned sz = g.size();
-        for (unsigned i = 0; i < sz; i++) {
+        for (unsigned i = 0; i < sz; ++i) {
             checkpoint();
             quick_for_each_expr(proc, visited, g.form(i));
         }
         
-        TRACE("reduce_args", tout << "non_candidates:\n";
+        TRACE(reduce_args, tout << "non_candidates:\n";
                 for (func_decl* d : non_candidates)
                     tout << d->get_name() << "\n";
               );
@@ -241,7 +210,7 @@ struct reduce_args_tactic::imp {
         decl2args.reset();
         populate_decl2args_proc proc(m, m_bv, non_candidates, decl2args);
         unsigned sz = g.size();
-        for (unsigned i = 0; i < sz; i++) {
+        for (unsigned i = 0; i < sz; ++i) {
             checkpoint();
             quick_for_each_expr(proc, visited, g.form(i));
         }
@@ -250,7 +219,7 @@ struct reduce_args_tactic::imp {
         ptr_buffer<func_decl> bad_decls;
         for (auto const& [k, v] : decl2args) {
             bool is_zero = true;
-            for (unsigned i = 0; i < v.size() && is_zero; i++) {
+            for (unsigned i = 0; i < v.size() && is_zero; ++i) {
                 if (v.get(i))
                     is_zero = false;
             }
@@ -261,7 +230,7 @@ struct reduce_args_tactic::imp {
         for (func_decl* a : bad_decls)
             decl2args.erase(a);
 
-        TRACE("reduce_args", tout << "decl2args:" << std::endl;
+        TRACE(reduce_args, tout << "decl2args:" << std::endl;
               for (auto const& [k, v] : decl2args) {
                   tout << k->get_name() << ": ";
                   for (unsigned i = 0; i < v.size(); ++i)
@@ -278,7 +247,7 @@ struct reduce_args_tactic::imp {
             // compute the hash-code using only the arguments where m_bv is true.
             unsigned a = 0x9e3779b9;
             unsigned num_args = n->get_num_args();
-            for (unsigned i = 0; i < num_args; i++) {
+            for (unsigned i = 0; i < num_args; ++i) {
                 if (!m_bv.get(i)) 
                     continue; // ignore argument
                 a = hash_u_u(a, n->get_arg(i)->get_id());
@@ -295,7 +264,7 @@ struct reduce_args_tactic::imp {
             // compare only the arguments where m_bv is true
             SASSERT(n1->get_num_args() == n2->get_num_args());
             unsigned num_args = n1->get_num_args();
-            for (unsigned i = 0; i < num_args; i++) {
+            for (unsigned i = 0; i < num_args; ++i) {
                 if (!m_bv.get(i)) 
                     continue; // ignore argument
                 if (n1->get_arg(i) != n2->get_arg(i))
@@ -325,14 +294,17 @@ struct reduce_args_tactic::imp {
             }
         }
     };
+
+    friend struct reduce_args_rw_cfg;
+    friend struct reduce_args_rw;
     
     struct reduce_args_rw_cfg : public default_rewriter_cfg {
         ast_manager &                    m;
-        imp &                            m_owner;
+        reduce_args_tactic &             m_owner;
         obj_map<func_decl, bit_vector> & m_decl2args;
         decl2arg2func_map &              m_decl2arg2funcs;
         
-        reduce_args_rw_cfg(imp & owner, obj_map<func_decl, bit_vector> & decl2args, decl2arg2func_map & decl2arg2funcs):
+        reduce_args_rw_cfg(reduce_args_tactic & owner, obj_map<func_decl, bit_vector> & decl2args, decl2arg2func_map & decl2arg2funcs):
             m(owner.m),
             m_owner(owner),
             m_decl2args(decl2args),
@@ -376,7 +348,7 @@ struct reduce_args_tactic::imp {
             }
 
             ptr_buffer<expr> new_args;
-            for (unsigned i = 0; i < num; i++) {
+            for (unsigned i = 0; i < num; ++i) {
                 if (!bv.get(i))
                     new_args.push_back(args[i]);
             }
@@ -388,7 +360,7 @@ struct reduce_args_tactic::imp {
     struct reduce_args_rw : rewriter_tpl<reduce_args_rw_cfg> {
         reduce_args_rw_cfg m_cfg;
     public:
-        reduce_args_rw(imp & owner, obj_map<func_decl, bit_vector> & decl2args, decl2arg2func_map & decl2arg2funcs):
+        reduce_args_rw(reduce_args_tactic & owner, obj_map<func_decl, bit_vector> & decl2args, decl2arg2func_map & decl2arg2funcs):
             rewriter_tpl<reduce_args_rw_cfg>(owner.m, false, m_cfg),
             m_cfg(owner, decl2args, decl2arg2funcs) {
         }
@@ -409,7 +381,7 @@ struct reduce_args_tactic::imp {
             bit_vector & bv = decl2args.find(f);
             new_vars.reset();
             new_args.reset();
-            for (unsigned i = 0; i < f->get_arity(); i++) {
+            for (unsigned i = 0; i < f->get_arity(); ++i) {
                 new_vars.push_back(m.mk_var(i, f->get_domain(i)));
                 if (!bv.get(i))
                     new_args.push_back(new_vars.back());
@@ -422,7 +394,7 @@ struct reduce_args_tactic::imp {
                 }
                 else {
                     new_eqs.reset();
-                    for (unsigned i = 0; i < f->get_arity(); i++) {
+                    for (unsigned i = 0; i < f->get_arity(); ++i) {
                         if (bv.get(i))
                             new_eqs.push_back(m.mk_eq(new_vars.get(i), t->get_arg(i)));
                     }
@@ -440,7 +412,7 @@ struct reduce_args_tactic::imp {
     void operator()(goal & g) {
         if (g.inconsistent())
             return;
-        TRACE("reduce_args", g.display(tout););
+        TRACE(reduce_args, g.display(tout););
         tactic_report report("reduce-args", g);
         obj_hashtable<func_decl> non_candidates;
         obj_map<func_decl, bit_vector> decl2args;
@@ -453,14 +425,13 @@ struct reduce_args_tactic::imp {
         reduce_args_ctx ctx(m);
         reduce_args_rw rw(*this, decl2args, ctx.m_decl2arg2funcs);
         
-        unsigned sz = g.size();
-        for (unsigned i = 0; i < sz; i++) {
+        unsigned idx = 0;
+        for (auto [f, dep, pr] : g) {
             if (g.inconsistent())
                 break;
-            expr * f = g.form(i);
             expr_ref new_f(m);
             rw(f, new_f);
-            g.update(i, new_f);
+            g.update(idx++, new_f);
         }
 
         report_tactic_progress(":reduced-funcs", decl2args.size());
@@ -468,45 +439,45 @@ struct reduce_args_tactic::imp {
         if (g.models_enabled())
             g.add(mk_mc(decl2args, ctx.m_decl2arg2funcs));
 
-        TRACE("reduce_args", g.display(tout); if (g.mc()) g.mc()->display(tout););
+        TRACE(reduce_args, g.display(tout); if (g.mc()) g.mc()->display(tout););
+    }
+
+public:
+    reduce_args_tactic(ast_manager & m) :
+        m_vars(m),
+        m(m),
+        m_bv(m),
+        m_ar(m) {
+    }
+
+    tactic * translate(ast_manager & m) override {
+        return alloc(reduce_args_tactic, m);
+    }
+
+    char const* name() const override { return "reduce_args"; }
+
+    void operator()(goal_ref const & g, goal_ref_buffer & result) override {
+        fail_if_unsat_core_generation("reduce-args", g);
+        result.reset();
+        if (!m.proofs_enabled()) {
+            operator()(*(g.get()));
+        }
+        g->inc_depth();
+        result.push_back(g.get());
+    }
+
+    void cleanup() override {}
+
+    void user_propagate_register_expr(expr* e) override {
+        m_vars.push_back(e);
+    }
+
+    void user_propagate_clear() override {
+        m_vars.reset();
     }
 };
-
-reduce_args_tactic::reduce_args_tactic(ast_manager & m) {
-    expr_ref_vector vars(m);
-    m_imp = alloc(imp, m);
 }
 
-reduce_args_tactic::~reduce_args_tactic() {
-    dealloc(m_imp);
+tactic * mk_reduce_args_tactic(ast_manager & m, params_ref const & p) {
+    return clean(alloc(reduce_args_tactic, m));
 }
-
-void reduce_args_tactic::operator()(goal_ref const & g, 
-                                    goal_ref_buffer & result) {
-    fail_if_unsat_core_generation("reduce-args", g);
-    result.reset();
-    if (!m_imp->m.proofs_enabled()) {
-        m_imp->operator()(*(g.get()));
-    }
-    g->inc_depth();
-    result.push_back(g.get());
-}
-
-void reduce_args_tactic::cleanup() {
-    ast_manager & m   = m_imp->m;
-    expr_ref_vector vars = m_imp->m_vars;
-    m_imp->~imp();
-    m_imp = new (m_imp) imp(m);
-    m_imp->m_vars.append(vars);
-}
-
-void reduce_args_tactic::user_propagate_register_expr(expr* e) {
-    m_imp->m_vars.push_back(e);
-}
-
-void reduce_args_tactic::user_propagate_clear() {
-    m_imp->m_vars.reset();
-}
-
-
-
