@@ -34,16 +34,16 @@ model_converter * fpa2bv_model_converter::translate(ast_translation & translator
 
 void fpa2bv_model_converter::convert(model_core * mc, model * float_mdl) {
     TRACE(fpa2bv_mc, tout << "BV Model: " << std::endl;
-        for (unsigned i = 0; i < mc->get_num_constants(); i++)
+        for (unsigned i = 0; i < mc->get_num_constants(); ++i)
             tout << mc->get_constant(i)->get_name() << " --> " <<
                     mk_ismt2_pp(mc->get_const_interp(mc->get_constant(i)), m) << std::endl;
-        for (unsigned i = 0; i < mc->get_num_functions(); i++) {
+        for (unsigned i = 0; i < mc->get_num_functions(); ++i) {
             func_decl * f = mc->get_function(i);
             tout << f->get_name() << "(...) := " << std::endl;
             func_interp * fi = mc->get_func_interp(f);
-            for (unsigned j = 0; j < fi->num_entries(); j++) {
+            for (unsigned j = 0; j < fi->num_entries(); ++j) {
                 func_entry const * fe = fi->get_entry(j);
-                for (unsigned k = 0; k < f->get_arity(); k++)
+                for (unsigned k = 0; k < f->get_arity(); ++k)
                     tout << mk_ismt2_pp(fe->get_arg(k), m) << " ";
                 tout << "--> " << mk_ismt2_pp(fe->get_result(), m) << std::endl;
             }
@@ -58,7 +58,7 @@ void fpa2bv_model_converter::convert(model_core * mc, model * float_mdl) {
 
     // Keep all the non-float constants.
     unsigned sz = mc->get_num_constants();
-    for (unsigned i = 0; i < sz; i++) {
+    for (unsigned i = 0; i < sz; ++i) {
         func_decl * c = mc->get_constant(i);
         if (!seen.contains(c))
             float_mdl->register_decl(c, mc->get_const_interp(c));
@@ -66,7 +66,7 @@ void fpa2bv_model_converter::convert(model_core * mc, model * float_mdl) {
 
     // And keep everything else
     sz = mc->get_num_functions();
-    for (unsigned i = 0; i < sz; i++) {
+    for (unsigned i = 0; i < sz; ++i) {
         func_decl * f = mc->get_function(i);
         if (!seen.contains(f)) {
             TRACE(fpa2bv_mc, tout << "Keeping: " << mk_ismt2_pp(f, m) << std::endl;);
@@ -76,7 +76,7 @@ void fpa2bv_model_converter::convert(model_core * mc, model * float_mdl) {
     }
 
     sz = mc->get_num_uninterpreted_sorts();
-    for (unsigned i = 0; i < sz; i++) {
+    for (unsigned i = 0; i < sz; ++i) {
         sort * s = mc->get_uninterpreted_sort(i);
         ptr_vector<expr> u = mc->get_universe(s);
         float_mdl->register_usort(s, u.size(), u.data());
