@@ -16,13 +16,13 @@ Author:
 Revision History:
 
 --*/
-#include"goal_shared_occs.h"
+#include "tactic/goal_shared_occs.h"
 
 void goal_shared_occs::operator()(goal const & g) {
     m_occs.reset();
     shared_occs_mark visited;
     unsigned sz = g.size();
-    for (unsigned i = 0; i < sz; i++) {
+    for (unsigned i = 0; i < sz; ++i) {
         expr * t = g.form(i);
         m_occs(t, visited);
     }
