@@ -128,7 +128,7 @@ public:
         }
         else {
             goal_ref_buffer r2;
-            for (unsigned i = 0; i < r1_size; i++) {                                                        
+            for (unsigned i = 0; i < r1_size; ++i) {                                                        
                 goal_ref g = r1[i];                                                                       
                 r2.reset();
                 m_t2->operator()(g, r2);
@@ -200,6 +200,10 @@ public:
         m_t2->user_propagate_register_diseq(diseq_eh);
     }
 
+    void user_propagate_register_on_binding(user_propagator::binding_eh_t& binding_eh) override {
+        m_t2->user_propagate_register_on_binding(binding_eh);
+    }
+
     void user_propagate_register_expr(expr* e) override {
         m_t1->user_propagate_register_expr(e);
         m_t2->user_propagate_register_expr(e);
@@ -281,14 +285,14 @@ protected:
 
 public:
     nary_tactical(unsigned num, tactic * const * ts) {
-        for (unsigned i = 0; i < num; i++) {
+        for (unsigned i = 0; i < num; ++i) {
             SASSERT(ts[i]);
             m_ts.push_back(ts[i]);
         }
     }
 
     void updt_params(params_ref const & p) override {
-        TRACE("nary_tactical_updt_params", tout << "updt_params: " << p << "\n";);
+        TRACE(nary_tactical_updt_params, tout << "updt_params: " << p << "\n";);
         for (tactic* t : m_ts) t->updt_params(p);
     }
     
@@ -343,7 +347,7 @@ public:
         goal orig(*(in.get()));
         unsigned sz = m_ts.size();
         unsigned i;
-        for (i = 0; i < sz; i++) {
+        for (i = 0; i < sz; ++i) {
             tactic * t = m_ts[i];
             SASSERT(sz > 0);
             if (i < sz - 1) {
@@ -489,7 +493,7 @@ public:
         goal_ref_vector                in_copies;
         tactic_ref_vector              ts;
         unsigned sz = m_ts.size();
-        for (unsigned i = 0; i < sz; i++) {
+        for (unsigned i = 0; i < sz; ++i) {
             ast_manager * new_m = alloc(ast_manager, m, !m.proof_mode());
             managers.push_back(new_m);
             ast_translation translator(m, *new_m);
@@ -519,7 +523,7 @@ public:
                     }
                 }                
                 if (first) {
-                    for (unsigned j = 0; j < sz; j++) {
+                    for (unsigned j = 0; j < sz; ++j) {
                         if (i != j) {
                             managers[j]->limit().cancel();
                         }
@@ -644,7 +648,7 @@ public:
             tactic_ref_vector              ts2;
             goal_ref_vector                g_copies;
 
-            for (unsigned i = 0; i < r1_size; i++) {
+            for (unsigned i = 0; i < r1_size; ++i) {
                 ast_manager * new_m = alloc(ast_manager, m, !m.proof_mode());
                 managers.push_back(new_m);
                 ast_translation translator(m, *new_m);
@@ -711,7 +715,7 @@ public:
                 }
 
                 if (curr_failed) {
-                    for (unsigned j = 0; j < r1_size; j++) {
+                    for (unsigned j = 0; j < r1_size; ++j) {
                         if (static_cast<unsigned>(i) != j) {
                             managers[j]->limit().cancel();
                         }
@@ -732,7 +736,7 @@ public:
                                 }
                             }
                             if (first) {
-                                for (unsigned j = 0; j < r1_size; j++) {
+                                for (unsigned j = 0; j < r1_size; ++j) {
                                     if (static_cast<unsigned>(i) != j) {
                                         managers[j]->limit().cancel();
                                     }
@@ -790,12 +794,12 @@ public:
                 return;
             
             expr_dependency_ref core(m);
-            for (unsigned i = 0; i < r1_size; i++) {
+            for (unsigned i = 0; i < r1_size; ++i) {
                 ast_translation translator(*(managers[i]), m, false);
                 goal_ref_buffer * r = goals_vect[i];
                 unsigned j = result.size();
                 if (r != nullptr) {
-                    for (unsigned k = 0; k < r->size(); k++) {
+                    for (unsigned k = 0; k < r->size(); ++k) {
                         result.push_back((*r)[k]->translate(translator));
                     }
                 }
@@ -936,7 +940,7 @@ class repeat_tactical : public unary_tactical {
         }                      
 
 		goal_ref_buffer            r2;
-		for (unsigned i = 0; i < r1_size; i++) {
+		for (unsigned i = 0; i < r1_size; ++i) {
 			goal_ref g = r1[i];
 			r2.reset();
 			operator()(depth + 1, g, r2);
@@ -1076,7 +1080,7 @@ public:
     char const* name() const override { return "using_params"; }
 
     void updt_params(params_ref const & p) override {
-        TRACE("using_params", 
+        TRACE(using_params, 
               tout << "before p: " << p << "\n";
               tout << "m_params: " << m_params << "\n";);
         
@@ -1084,7 +1088,7 @@ public:
         new_p.append(m_params);
         unary_tactical::updt_params(new_p);
         
-        TRACE("using_params", 
+        TRACE(using_params, 
               tout << "after p: " << p << "\n";
               tout << "m_params: " << m_params << "\n";
               tout << "new_p: " << new_p << "\n";);
