@@ -13,7 +13,7 @@ Copyright (c) 2015 Microsoft Corporation
 #include "util/sorting_network.h"
 #include "smt/smt_kernel.h"
 #include "model/model_smt2_pp.h"
-#include "smt/params/smt_params.h"
+#include "params/smt_params.h"
 #include "ast/ast_util.h"
 #include "ast/rewriter/expr_safe_replace.h"
 #include "ast/rewriter/th_rewriter.h"
@@ -173,7 +173,7 @@ class test_doc_cls {
             default: break;
             }
         }
-        result = mk_and(m, conjs.size(), conjs.data());
+        result = mk_and(conjs);
         return result;
     }
 
@@ -197,7 +197,7 @@ class test_doc_cls {
                 break;
             }
         }
-        result = mk_and(m, conjs.size(), conjs.data());
+        result = mk_and(conjs);
         return result;
     }
 
@@ -208,7 +208,7 @@ class test_doc_cls {
         for (unsigned i = 0; i < d.neg().size(); ++i) {
             conjs.push_back(m.mk_not(to_formula(d.neg()[i], m2)));
         }
-        result = mk_and(m, conjs.size(), conjs.data());
+        result = mk_and(conjs);
         return result;
     }
 
@@ -218,13 +218,13 @@ class test_doc_cls {
         for (unsigned i = 0; i < ud.size(); ++i) {
             disjs.push_back(to_formula(ud[i], m2));
         }
-        result = mk_or(m, disjs.size(), disjs.data());
+        result = mk_or(disjs);
         return result;
     }
 
     void project(doc const& d, doc_manager& m2, const bit_vector& to_delete, doc_ref& result) {
         result = dm.project(m2, to_delete, d);
-        TRACE("doc",
+        TRACE(doc,
               for (unsigned i = 0; i < m_vars.size(); ++i) {
                   tout << (to_delete.get(i)?"0":"1");
               }
@@ -250,7 +250,7 @@ class test_doc_cls {
         doc_manager m2(num_bits);
         doc_ref result(m2);
         project(*d, m2, to_delete, result);
-        TRACE("doc",              
+        TRACE(doc,              
               dm.display(tout, *d) << "\n";
               m2.display(tout, *result) << "\n";);
         fml2 = to_formula(*result, m2);
@@ -299,7 +299,7 @@ class test_doc_cls {
             fmls.push_back(m.mk_not(mk_conj(*t)));
             d->neg().push_back(t);
         }
-        fml1 = mk_and(m, fmls.size(), fmls.data());
+        fml1 = mk_and(fmls);
         bool_vector to_merge(N, false);
         bit_vector discard_cols;
         discard_cols.resize(N, false);
@@ -321,7 +321,7 @@ class test_doc_cls {
             }
         }
         eqs.push_back(to_formula(*d, dm));
-        fml1 = mk_and(m, eqs.size(), eqs.data());
+        fml1 = mk_and(eqs);
         if (dm.merge(*d, lo, 1, equalities, discard_cols)) {
             fml2 = to_formula(*d, dm);
         }
@@ -342,7 +342,7 @@ class test_doc_cls {
         solver.assert_expr(fml);
         lbool res = solver.check();
         if (res != l_false) {
-            TRACE("doc",
+            TRACE(doc,
                   tout << mk_pp(fml1, m) << "\n";
                   tout << mk_pp(fml2, m) << "\n";
                   );
@@ -459,11 +459,11 @@ public:
             mk_rand_udoc(3, 3, d2);
             fml1 = to_formula(d1, dm);
             fml2 = to_formula(d2, dm);
-            TRACE("doc", 
+            TRACE(doc, 
                   d1.display(dm, tout) << "\n";
                   d2.display(dm, tout) << "\n";);
             d1.intersect(dm, d2);
-            TRACE("doc", d1.display(dm, tout) << "\n";);
+            TRACE(doc, d1.display(dm, tout) << "\n";);
             ENSURE(d1.well_formed(dm));
             fml3 = to_formula(d1, dm);
             fml1 = m.mk_and(fml1, fml2);
