@@ -19,12 +19,14 @@ Revision History:
 #include "util/trace.h"
 #include "util/debug.h"
 #include "util/memory_manager.h"
-#include "util/optional.h"
+#include "math/lp/lp_utils.h"
+#include "ast/dl_decl_plugin.h"
+#include <optional>
+#include <unordered_map>
 
 static void tst1() {
-    optional<int> v;
-    ENSURE(!v);
-    ENSURE(v == false);
+    std::optional<int> v;
+    ENSURE(!v.has_value());
     v = 10;
     ENSURE(v);
     ENSURE(*v == 10);
@@ -45,7 +47,7 @@ struct OptFoo {
 };
 
 static void tst2() {
-    optional<OptFoo> v;
+    std::optional<OptFoo> v;
     ENSURE(!v);
     v = OptFoo(10, 20);
     ENSURE(v->m_x == 10);
@@ -57,7 +59,7 @@ static void tst2() {
 }
 
 static void tst3() {
-    optional<int *> v;
+    std::optional<int *> v;
     ENSURE(!v);
     int x = 10;
     v = &x;
@@ -67,9 +69,32 @@ static void tst3() {
     ENSURE(*(*v) == 10);
 }
 
+static void tst_try_get_value() {
+    std::unordered_map<int, std::string> map;
+    map[1] = "one";
+    map[2] = "two";
+    map[3] = "three";
+    
+    // Test successful retrieval
+    auto result1 = try_get_value(map, 1);
+    ENSURE(result1.has_value());
+    ENSURE(*result1 == "one");
+    
+    auto result2 = try_get_value(map, 2);
+    ENSURE(result2.has_value());
+    ENSURE(*result2 == "two");
+    
+    // Test unsuccessful retrieval
+    auto result_missing = try_get_value(map, 999);
+    ENSURE(!result_missing.has_value());
+    
+    TRACE(optional, tout << "try_get_value tests passed\n";);
+}
+
 void tst_optional() {
     tst1();
     tst2();
     tst3();
+    tst_try_get_value();
 }
 
