@@ -40,7 +40,7 @@ public:
 
     void reset() {
         auto sz = this->size();
-        for (unsigned i = 0; i < sz; i++) {
+        for (unsigned i = 0; i < sz; ++i) {
             m().del(this->operator[](i));
         }
         svector<typename Manager::numeral>::reset();
@@ -61,7 +61,7 @@ public:
         unsigned old_sz = this->size();
         if (old_sz == sz)
             return;
-        for (unsigned i = sz; i < old_sz; i++)
+        for (unsigned i = sz; i < old_sz; ++i)
             m().del(this->operator[](i));
         svector<typename Manager::numeral>::shrink(sz);
     }
