@@ -24,7 +24,7 @@ Revision History:
 #include "util/hash.h"
 
 struct str_hash_proc { 
-    unsigned operator()(char const * s) const { return string_hash(s, static_cast<unsigned>(strlen(s)), 17); } 
+    unsigned operator()(char const * s) const { return string_hash(std::string_view(s), 17); } 
 };
 struct str_eq_proc { bool operator()(char const * s1, char const * s2) const { return strcmp(s1, s2) == 0; } }; 
 typedef ptr_hashtable<const char, str_hash_proc, str_eq_proc> str_hashtable;
