@@ -16,8 +16,7 @@
   Revision History:
 
   --*/
-#ifndef STRING_BUFFER_H_
-#define STRING_BUFFER_H_
+#pragma once
 
 #include<cstdio>
 #include<string>
@@ -44,8 +43,6 @@ class string_buffer {
         m_buffer   = new_buffer;
     }
 
-    static const unsigned c_buffer_size = 24;
-
 public:  
     string_buffer():
         m_buffer(m_initial_buffer),
@@ -81,35 +78,33 @@ public:
         m_pos += len;
     }
 
+    void append(const std::string &str) {
+        size_t len     = str.size();
+        size_t new_pos = m_pos + len;
+        while (new_pos > m_capacity) {
+            expand();
+        }
+        memcpy(m_buffer + m_pos, str.c_str(), len);
+        m_pos += len;
+    }
+
     void append(int n) {
-        char buffer[c_buffer_size]; 
-        SPRINTF_D(buffer, n);
-        append(buffer);
+        auto str = std::to_string(n);
+        append(str.c_str());
     }
 
     void append(unsigned n) {
-        char buffer[c_buffer_size]; 
-        SPRINTF_U(buffer, n);
-        append(buffer);
+        auto str = std::to_string(n);
+        append(str.c_str());
     }
 
     void append(long n) {
-        char buffer[c_buffer_size]; 
-#ifdef _WINDOWS
-        sprintf_s(buffer, Z3_ARRAYSIZE(buffer), "%ld", n);
-#else
-        sprintf(buffer, "%ld", n);
-#endif
-        append(buffer);
+        auto str = std::to_string(n);
+        append(str.c_str());
     }
 
     void append(bool b) {
-        if (b) {
-            append("true");
-        }
-        else {
-            append("false");
-        }
+        append(b ? "true" : "false");
     }
 
     unsigned size() const {
@@ -136,6 +131,12 @@ inline string_buffer<SZ> & operator<<(string_buffer<SZ> & buffer, const char * s
     return buffer;
 }
 
+template<unsigned SZ>
+inline string_buffer<SZ> & operator<<(string_buffer<SZ> & buffer, const std::string &str) {
+    buffer.append(str);
+    return buffer;
+}
+
 template<unsigned SZ>
 inline string_buffer<SZ> & operator<<(string_buffer<SZ> & buffer, char c) {
     buffer.append(c);
@@ -171,5 +172,3 @@ inline string_buffer<SZ1> & operator<<(string_buffer<SZ1> & buffer1, const strin
     buffer1.append(buffer2.c_str());
     return buffer1;
 }
-
-#endif
