@@ -17,7 +17,7 @@ Revision History:
 
 --*/
 #pragma once
-#include<iostream>
+#include<ostream>
 #include<stdarg.h>
 
 void send_warnings_to_stdout(bool flag);
@@ -28,6 +28,8 @@ void set_error_stream(std::ostream* strm);
 
 void set_warning_stream(std::ostream* strm);
 
+std::ostream* warning_stream();
+
 void warning_msg(const char * msg, ...);
 
 void format2ostream(std::ostream& out, char const* fmt, va_list args);
